# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .contact import Contact
from .formatted_text import FormattedText
from .input_file import InputFile
from .input_thumbnail import InputThumbnail
from .invoice import Invoice
from .location import Location
from .message_copy_options import MessageCopyOptions
from .poll_type import PollType
from .venue import Venue
from ..base_object import BaseObject


class InputMessageContent(BaseObject):
    """
    The content of a message to send
    
    """

    ID: str = Field("inputMessageContent", alias="@type")


class InputMessageAnimation(InputMessageContent):
    """
    An animation message (GIF-style).
    
    Params:
        animation (:class:`InputFile`)
            Animation file to be sent
        
        thumbnail (:class:`InputThumbnail`)
            Animation thumbnail, if available
        
        added_sticker_file_ids (:obj:`list[int]`)
            File identifiers of the stickers added to the animation, if applicable
        
        duration (:class:`int`)
            Duration of the animation, in seconds
        
        width (:class:`int`)
            Width of the animation; may be replaced by the server
        
        height (:class:`int`)
            Height of the animation; may be replaced by the server
        
        caption (:class:`FormattedText`)
            Animation caption; 0-GetOption("message_caption_length_max") characters
        
    """

    ID: str = Field("inputMessageAnimation", alias="@type")
    animation: InputFile
    thumbnail: InputThumbnail
    added_sticker_file_ids: list[int]
    duration: int
    width: int
    height: int
    caption: FormattedText

    @staticmethod
    def read(q: dict) -> InputMessageAnimation:
        return InputMessageAnimation.construct(**q)


class InputMessageAudio(InputMessageContent):
    """
    An audio message
    
    Params:
        audio (:class:`InputFile`)
            Audio file to be sent
        
        album_cover_thumbnail (:class:`InputThumbnail`)
            Thumbnail of the cover for the album, if available
        
        duration (:class:`int`)
            Duration of the audio, in seconds; may be replaced by the server
        
        title (:class:`str`)
            Title of the audio; 0-64 characters; may be replaced by the server
        
        performer (:class:`str`)
            Performer of the audio; 0-64 characters, may be replaced by the server
        
        caption (:class:`FormattedText`)
            Audio caption; 0-GetOption("message_caption_length_max") characters
        
    """

    ID: str = Field("inputMessageAudio", alias="@type")
    audio: InputFile
    album_cover_thumbnail: InputThumbnail
    duration: int
    title: typing.Optional[str] = Field(None, max_length=64)
    performer: typing.Optional[str] = Field(None, max_length=64)
    caption: FormattedText

    @staticmethod
    def read(q: dict) -> InputMessageAudio:
        return InputMessageAudio.construct(**q)


class InputMessageContact(InputMessageContent):
    """
    A message containing a user contact
    
    Params:
        contact (:class:`Contact`)
            Contact to send
        
    """

    ID: str = Field("inputMessageContact", alias="@type")
    contact: Contact

    @staticmethod
    def read(q: dict) -> InputMessageContact:
        return InputMessageContact.construct(**q)


class InputMessageDice(InputMessageContent):
    """
    A dice message
    
    Params:
        emoji (:class:`str`)
            Emoji on which the dice throw animation is based
        
        clear_draft (:class:`bool`)
            True, if a chat message draft should be deleted
        
    """

    ID: str = Field("inputMessageDice", alias="@type")
    emoji: str
    clear_draft: bool

    @staticmethod
    def read(q: dict) -> InputMessageDice:
        return InputMessageDice.construct(**q)


class InputMessageDocument(InputMessageContent):
    """
    A document message (general file)
    
    Params:
        document (:class:`InputFile`)
            Document to be sent
        
        thumbnail (:class:`InputThumbnail`)
            Document thumbnail, if available
        
        disable_content_type_detection (:class:`bool`)
            If true, automatic file type detection will be disabled and the document will be always sent as file. Always true for files sent to secret chats
        
        caption (:class:`FormattedText`)
            Document caption; 0-GetOption("message_caption_length_max") characters
        
    """

    ID: str = Field("inputMessageDocument", alias="@type")
    document: InputFile
    thumbnail: InputThumbnail
    disable_content_type_detection: bool
    caption: FormattedText

    @staticmethod
    def read(q: dict) -> InputMessageDocument:
        return InputMessageDocument.construct(**q)


class InputMessageForwarded(InputMessageContent):
    """
    A forwarded message
    
    Params:
        from_chat_id (:class:`int`)
            Identifier for the chat this forwarded message came from
        
        message_id (:class:`int`)
            Identifier of the message to forward
        
        in_game_share (:class:`bool`)
            True, if a game message should be shared within a launched game; applies only to game messages
        
        copy_options (:class:`MessageCopyOptions`)
            Options to be used to copy content of the message without a link to the original message
        
    """

    ID: str = Field("inputMessageForwarded", alias="@type")
    from_chat_id: int
    message_id: int
    in_game_share: bool
    copy_options: MessageCopyOptions

    @staticmethod
    def read(q: dict) -> InputMessageForwarded:
        return InputMessageForwarded.construct(**q)


class InputMessageGame(InputMessageContent):
    """
    A message with a game; not supported for channels or secret chats
    
    Params:
        bot_user_id (:class:`int`)
            User identifier of the bot that owns the game
        
        game_short_name (:class:`str`)
            Short name of the game
        
    """

    ID: str = Field("inputMessageGame", alias="@type")
    bot_user_id: int
    game_short_name: str

    @staticmethod
    def read(q: dict) -> InputMessageGame:
        return InputMessageGame.construct(**q)


class InputMessageInvoice(InputMessageContent):
    """
    A message with an invoice; can be used only by bots and only in private chats
    
    Params:
        invoice (:class:`Invoice`)
            Invoice
        
        title (:class:`str`)
            Product title; 1-32 characters
        
        param_description (:class:`str`)
            Product description; 0-255 characters
        
        photo_url (:class:`str`)
            Product photo URL; optional
        
        photo_size (:class:`int`)
            Product photo size
        
        photo_width (:class:`int`)
            Product photo width
        
        photo_height (:class:`int`)
            Product photo height
        
        payload (:class:`str`)
            The invoice payload
        
        provider_token (:class:`str`)
            Payment provider token
        
        provider_data (:class:`str`)
            JSON-encoded data about the invoice, which will be shared with the payment provider
        
        start_parameter (:class:`str`)
            Unique invoice bot start_parameter for the generation of this invoice
        
    """

    ID: str = Field("inputMessageInvoice", alias="@type")
    invoice: Invoice
    title: str = Field(..., min_length=1, max_length=32)
    param_description: typing.Optional[str] = Field(None, max_length=255)
    photo_url: str
    photo_size: int
    photo_width: int
    photo_height: int
    payload: str
    provider_token: str
    provider_data: str
    start_parameter: str

    @staticmethod
    def read(q: dict) -> InputMessageInvoice:
        return InputMessageInvoice.construct(**q)


class InputMessageLocation(InputMessageContent):
    """
    A message with a location
    
    Params:
        location (:class:`Location`)
            Location to be sent
        
        live_period (:class:`int`)
            Period for which the location can be updated, in seconds; should be between 60 and 86400 for a live location and 0 otherwise
        
        heading (:class:`int`)
            For live locations, a direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
        
        proximity_alert_radius (:class:`int`)
            For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled. Can't be enabled in channels and Saved Messages
        
    """

    ID: str = Field("inputMessageLocation", alias="@type")
    location: Location
    live_period: int
    heading: int
    proximity_alert_radius: int

    @staticmethod
    def read(q: dict) -> InputMessageLocation:
        return InputMessageLocation.construct(**q)


class InputMessagePhoto(InputMessageContent):
    """
    A photo message
    
    Params:
        photo (:class:`InputFile`)
            Photo to send
        
        thumbnail (:class:`InputThumbnail`)
            Photo thumbnail to be sent, this is sent to the other party in secret chats only
        
        added_sticker_file_ids (:obj:`list[int]`)
            File identifiers of the stickers added to the photo, if applicable
        
        width (:class:`int`)
            Photo width
        
        height (:class:`int`)
            Photo height
        
        caption (:class:`FormattedText`)
            Photo caption; 0-GetOption("message_caption_length_max") characters
        
        ttl (:class:`int`)
            Photo TTL (Time To Live), in seconds (0-60). A non-zero TTL can be specified only in private chats
        
    """

    ID: str = Field("inputMessagePhoto", alias="@type")
    photo: InputFile
    thumbnail: InputThumbnail
    added_sticker_file_ids: list[int]
    width: int
    height: int
    caption: FormattedText
    ttl: int

    @staticmethod
    def read(q: dict) -> InputMessagePhoto:
        return InputMessagePhoto.construct(**q)


class InputMessagePoll(InputMessageContent):
    """
    A message with a poll. Polls can't be sent to secret chats. Polls can be sent only to a private chat with a bot
    
    Params:
        question (:class:`str`)
            Poll question; 1-255 characters (up to 300 characters for bots)
        
        options (:obj:`list[str]`)
            List of poll answer options, 2-10 strings 1-100 characters each
        
        is_anonymous (:class:`bool`)
            True, if the poll voters are anonymous. Non-anonymous polls can't be sent or forwarded to channels
        
        type_ (:class:`PollType`)
            Type of the poll
        
        open_period (:class:`int`)
            Amount of time the poll will be active after creation, in seconds; for bots only
        
        close_date (:class:`int`)
            Point in time (Unix timestamp) when the poll will be automatically closed; for bots only
        
        is_closed (:class:`bool`)
            True, if the poll needs to be sent already closed; for bots only
        
    """

    ID: str = Field("inputMessagePoll", alias="@type")
    question: str = Field(..., min_length=1, max_length=255)
    options: list[str]
    is_anonymous: bool
    type_: PollType = Field(..., alias='type')
    open_period: int
    close_date: int
    is_closed: bool

    @staticmethod
    def read(q: dict) -> InputMessagePoll:
        return InputMessagePoll.construct(**q)


class InputMessageSticker(InputMessageContent):
    """
    A sticker message
    
    Params:
        sticker (:class:`InputFile`)
            Sticker to be sent
        
        thumbnail (:class:`InputThumbnail`)
            Sticker thumbnail, if available
        
        width (:class:`int`)
            Sticker width
        
        height (:class:`int`)
            Sticker height
        
        emoji (:class:`str`)
            Emoji used to choose the sticker
        
    """

    ID: str = Field("inputMessageSticker", alias="@type")
    sticker: InputFile
    thumbnail: InputThumbnail
    width: int
    height: int
    emoji: str

    @staticmethod
    def read(q: dict) -> InputMessageSticker:
        return InputMessageSticker.construct(**q)


class InputMessageText(InputMessageContent):
    """
    A text message
    
    Params:
        text (:class:`FormattedText`)
            Formatted text to be sent; 1-GetOption("message_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Code, Pre, PreCode, TextUrl and MentionName entities are allowed to be specified manually
        
        disable_web_page_preview (:class:`bool`)
            True, if rich web page previews for URLs in the message text should be disabled
        
        clear_draft (:class:`bool`)
            True, if a chat message draft should be deleted
        
    """

    ID: str = Field("inputMessageText", alias="@type")
    text: FormattedText
    disable_web_page_preview: bool
    clear_draft: bool

    @staticmethod
    def read(q: dict) -> InputMessageText:
        return InputMessageText.construct(**q)


class InputMessageVenue(InputMessageContent):
    """
    A message with information about a venue
    
    Params:
        venue (:class:`Venue`)
            Venue to send
        
    """

    ID: str = Field("inputMessageVenue", alias="@type")
    venue: Venue

    @staticmethod
    def read(q: dict) -> InputMessageVenue:
        return InputMessageVenue.construct(**q)


class InputMessageVideo(InputMessageContent):
    """
    A video message
    
    Params:
        video (:class:`InputFile`)
            Video to be sent
        
        thumbnail (:class:`InputThumbnail`)
            Video thumbnail, if available
        
        added_sticker_file_ids (:obj:`list[int]`)
            File identifiers of the stickers added to the video, if applicable
        
        duration (:class:`int`)
            Duration of the video, in seconds
        
        width (:class:`int`)
            Video width
        
        height (:class:`int`)
            Video height
        
        supports_streaming (:class:`bool`)
            True, if the video should be tried to be streamed
        
        caption (:class:`FormattedText`)
            Video caption; 0-GetOption("message_caption_length_max") characters
        
        ttl (:class:`int`)
            Video TTL (Time To Live), in seconds (0-60). A non-zero TTL can be specified only in private chats
        
    """

    ID: str = Field("inputMessageVideo", alias="@type")
    video: InputFile
    thumbnail: InputThumbnail
    added_sticker_file_ids: list[int]
    duration: int
    width: int
    height: int
    supports_streaming: bool
    caption: FormattedText
    ttl: int

    @staticmethod
    def read(q: dict) -> InputMessageVideo:
        return InputMessageVideo.construct(**q)


class InputMessageVideoNote(InputMessageContent):
    """
    A video note message
    
    Params:
        video_note (:class:`InputFile`)
            Video note to be sent
        
        thumbnail (:class:`InputThumbnail`)
            Video thumbnail, if available
        
        duration (:class:`int`)
            Duration of the video, in seconds
        
        length (:class:`int`)
            Video width and height; must be positive and not greater than 640
        
    """

    ID: str = Field("inputMessageVideoNote", alias="@type")
    video_note: InputFile
    thumbnail: InputThumbnail
    duration: int
    length: int

    @staticmethod
    def read(q: dict) -> InputMessageVideoNote:
        return InputMessageVideoNote.construct(**q)


class InputMessageVoiceNote(InputMessageContent):
    """
    A voice note message
    
    Params:
        voice_note (:class:`InputFile`)
            Voice note to be sent
        
        duration (:class:`int`)
            Duration of the voice note, in seconds
        
        waveform (:class:`str`)
            Waveform representation of the voice note, in 5-bit format
        
        caption (:class:`FormattedText`)
            Voice note caption; 0-GetOption("message_caption_length_max") characters
        
    """

    ID: str = Field("inputMessageVoiceNote", alias="@type")
    voice_note: InputFile
    duration: int
    waveform: str
    caption: FormattedText

    @staticmethod
    def read(q: dict) -> InputMessageVoiceNote:
        return InputMessageVoiceNote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .date import Date
from ..base_object import BaseObject


class PersonalDetails(BaseObject):
    """
    Contains the user's personal details
    
    Params:
        first_name (:class:`str`)
            First name of the user written in English; 1-255 characters
        
        middle_name (:class:`str`)
            Middle name of the user written in English; 0-255 characters
        
        last_name (:class:`str`)
            Last name of the user written in English; 1-255 characters
        
        native_first_name (:class:`str`)
            Native first name of the user; 1-255 characters
        
        native_middle_name (:class:`str`)
            Native middle name of the user; 0-255 characters
        
        native_last_name (:class:`str`)
            Native last name of the user; 1-255 characters
        
        birthdate (:class:`Date`)
            Birthdate of the user
        
        gender (:class:`str`)
            Gender of the user, "male" or "female"
        
        country_code (:class:`str`)
            A two-letter ISO 3166-1 alpha-2 country code of the user's country
        
        residence_country_code (:class:`str`)
            A two-letter ISO 3166-1 alpha-2 country code of the user's residence country
        
    """

    ID: str = Field("personalDetails", alias="@type")
    first_name: str = Field(..., min_length=1, max_length=255)
    middle_name: typing.Optional[str] = Field(None, max_length=255)
    last_name: str = Field(..., min_length=1, max_length=255)
    native_first_name: str = Field(..., min_length=1, max_length=255)
    native_middle_name: typing.Optional[str] = Field(None, max_length=255)
    native_last_name: str = Field(..., min_length=1, max_length=255)
    birthdate: Date
    gender: str
    country_code: str
    residence_country_code: str

    @staticmethod
    def read(q: dict) -> PersonalDetails:
        return PersonalDetails.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .test_int import TestInt
from ..base_object import BaseObject


class TestVectorIntObject(BaseObject):
    """
    A simple object containing a vector of objects that hold a number; for testing only
    
    Params:
        value (:obj:`list[TestInt]`)
            Vector of objects
        
    """

    ID: str = Field("testVectorIntObject", alias="@type")
    value: list[TestInt]

    @staticmethod
    def read(q: dict) -> TestVectorIntObject:
        return TestVectorIntObject.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLanguagePackString(BaseObject):
    """
    Returns a string stored in the local database from the specified localization target and language pack by its key. Returns a 404 error if the string is not found. Can be called synchronously
    
    Params:
        language_pack_database_path (:class:`str`)
            Path to the language pack database in which strings are stored
        
        localization_target (:class:`str`)
            Localization target to which the language pack belongs
        
        language_pack_id (:class:`str`)
            Language pack identifier
        
        key (:class:`str`)
            Language pack key of the string to be returned
        
    """

    ID: str = Field("getLanguagePackString", alias="@type")
    language_pack_database_path: str
    localization_target: str
    language_pack_id: str
    key: str

    @staticmethod
    def read(q: dict) -> GetLanguagePackString:
        return GetLanguagePackString.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetWebPageInstantView(BaseObject):
    """
    Returns an instant view version of a web page if available. Returns a 404 error if the web page has no instant view page
    
    Params:
        url (:class:`str`)
            The web page URL
        
        force_full (:class:`bool`)
            If true, the full instant view for the web page will be returned
        
    """

    ID: str = Field("getWebPageInstantView", alias="@type")
    url: str
    force_full: bool

    @staticmethod
    def read(q: dict) -> GetWebPageInstantView:
        return GetWebPageInstantView.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ToggleChatDefaultDisableNotification(BaseObject):
    """
    Changes the value of the default disable_notification parameter, used when a message is sent to a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        default_disable_notification (:class:`bool`)
            New value of default_disable_notification
        
    """

    ID: str = Field("toggleChatDefaultDisableNotification", alias="@type")
    chat_id: int
    default_disable_notification: bool

    @staticmethod
    def read(q: dict) -> ToggleChatDefaultDisableNotification:
        return ToggleChatDefaultDisableNotification.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputMessageContent, MessageSendOptions, ReplyMarkup


class SendMessage(BaseObject):
    """
    Sends a message. Returns the sent message
    
    Params:
        chat_id (:class:`int`)
            Target chat
        
        message_thread_id (:class:`int`)
            If not 0, a message thread identifier in which the message will be sent
        
        reply_to_message_id (:class:`int`)
            Identifier of the message to reply to or 0
        
        options (:class:`MessageSendOptions`)
            Options to be used to send the message
        
        reply_markup (:class:`ReplyMarkup`)
            Markup for replying to the message; for bots only
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent
        
    """

    ID: str = Field("sendMessage", alias="@type")
    chat_id: int
    message_thread_id: int
    reply_to_message_id: int
    options: MessageSendOptions
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> SendMessage:
        return SendMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetBankCardInfo(BaseObject):
    """
    Returns information about a bank card
    
    Params:
        bank_card_number (:class:`str`)
            The bank card number
        
    """

    ID: str = Field("getBankCardInfo", alias="@type")
    bank_card_number: str

    @staticmethod
    def read(q: dict) -> GetBankCardInfo:
        return GetBankCardInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message_scheduling_state import MessageSchedulingState
from ..base_object import BaseObject


class MessageSendOptions(BaseObject):
    """
    Options to be used when a message is sent
    
    Params:
        disable_notification (:class:`bool`)
            Pass true to disable notification for the message
        
        from_background (:class:`bool`)
            Pass true if the message is sent from the background
        
        scheduling_state (:class:`MessageSchedulingState`)
            Message scheduling state. Messages sent to a secret chat, live location messages and self-destructing messages can't be scheduled
        
    """

    ID: str = Field("messageSendOptions", alias="@type")
    disable_notification: bool
    from_background: bool
    scheduling_state: MessageSchedulingState

    @staticmethod
    def read(q: dict) -> MessageSendOptions:
        return MessageSendOptions.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AutoDownloadSettings(BaseObject):
    """
    Contains auto-download settings
    
    Params:
        is_auto_download_enabled (:class:`bool`)
            True, if the auto-download is enabled
        
        max_photo_file_size (:class:`int`)
            The maximum size of a photo file to be auto-downloaded
        
        max_video_file_size (:class:`int`)
            The maximum size of a video file to be auto-downloaded
        
        max_other_file_size (:class:`int`)
            The maximum size of other file types to be auto-downloaded
        
        video_upload_bitrate (:class:`int`)
            The maximum suggested bitrate for uploaded videos
        
        preload_large_videos (:class:`bool`)
            True, if the beginning of video files needs to be preloaded for instant playback
        
        preload_next_audio (:class:`bool`)
            True, if the next audio track needs to be preloaded while the user is listening to an audio file
        
        use_less_data_for_calls (:class:`bool`)
            True, if "use less data for calls" option needs to be enabled
        
    """

    ID: str = Field("autoDownloadSettings", alias="@type")
    is_auto_download_enabled: bool
    max_photo_file_size: int
    max_video_file_size: int
    max_other_file_size: int
    video_upload_bitrate: int
    preload_large_videos: bool
    preload_next_audio: bool
    use_less_data_for_calls: bool

    @staticmethod
    def read(q: dict) -> AutoDownloadSettings:
        return AutoDownloadSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLoginUrl(BaseObject):
    """
    Returns an HTTP URL which can be used to automatically authorize the user on a website after clicking an inline button of type inlineKeyboardButtonTypeLoginUrl. Use the method getLoginUrlInfo to find whether a prior user confirmation is needed. If an error is returned, then the button must be handled as an ordinary URL button
    
    Params:
        chat_id (:class:`int`)
            Chat identifier of the message with the button
        
        message_id (:class:`int`)
            Message identifier of the message with the button
        
        button_id (:class:`int`)
            Button identifier
        
        allow_write_access (:class:`bool`)
            True, if the user allowed the bot to send them messages
        
    """

    ID: str = Field("getLoginUrl", alias="@type")
    chat_id: int
    message_id: int
    button_id: int
    allow_write_access: bool

    @staticmethod
    def read(q: dict) -> GetLoginUrl:
        return GetLoginUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ProxyType


class TestProxy(BaseObject):
    """
    Sends a simple network request to the Telegram servers via proxy; for testing only. Can be called before authorization
    
    Params:
        server (:class:`str`)
            Proxy server IP address
        
        port (:class:`int`)
            Proxy server port
        
        type_ (:class:`ProxyType`)
            Proxy type
        
        dc_id (:class:`int`)
            Identifier of a datacenter, with which to test connection
        
        timeout (:class:`float`)
            The maximum overall timeout for the request
        
    """

    ID: str = Field("testProxy", alias="@type")
    server: str
    port: int
    type_: ProxyType = Field(..., alias='type')
    dc_id: int
    timeout: float

    @staticmethod
    def read(q: dict) -> TestProxy:
        return TestProxy.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatLocation


class SetChatLocation(BaseObject):
    """
    Changes the location of a chat. Available only for some location-based supergroups, use supergroupFullInfo.can_set_location to check whether the method is allowed to use
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        location (:class:`ChatLocation`)
            New location for the chat; must be valid and not null
        
    """

    ID: str = Field("setChatLocation", alias="@type")
    chat_id: int
    location: ChatLocation

    @staticmethod
    def read(q: dict) -> SetChatLocation:
        return SetChatLocation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .call_server_type import CallServerType
from ..base_object import BaseObject


class CallServer(BaseObject):
    """
    Describes a server for relaying call data
    
    Params:
        id (:class:`int`)
            Server identifier
        
        ip_address (:class:`str`)
            Server IPv4 address
        
        ipv6_address (:class:`str`)
            Server IPv6 address
        
        port (:class:`int`)
            Server port number
        
        type_ (:class:`CallServerType`)
            Server type
        
    """

    ID: str = Field("callServer", alias="@type")
    id: int
    ip_address: str
    ipv6_address: str
    port: int
    type_: CallServerType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> CallServer:
        return CallServer.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetGroupCallTitle(BaseObject):
    """
    Sets group call title. Requires groupCall.can_be_managed group call flag
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
        title (:class:`str`)
            New group call title; 1-64 characters
        
    """

    ID: str = Field("setGroupCallTitle", alias="@type")
    group_call_id: int
    title: str = Field(..., min_length=1, max_length=64)

    @staticmethod
    def read(q: dict) -> SetGroupCallTitle:
        return SetGroupCallTitle.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .poll_option import PollOption
from .poll_type import PollType
from ..base_object import BaseObject


class Poll(BaseObject):
    """
    Describes a poll
    
    Params:
        id (:class:`int`)
            Unique poll identifier
        
        question (:class:`str`)
            Poll question; 1-300 characters
        
        options (:obj:`list[PollOption]`)
            List of poll answer options
        
        total_voter_count (:class:`int`)
            Total number of voters, participating in the poll
        
        recent_voter_user_ids (:obj:`list[int]`)
            User identifiers of recent voters, if the poll is non-anonymous
        
        is_anonymous (:class:`bool`)
            True, if the poll is anonymous
        
        type_ (:class:`PollType`)
            Type of the poll
        
        open_period (:class:`int`)
            Amount of time the poll will be active after creation, in seconds
        
        close_date (:class:`int`)
            Point in time (Unix timestamp) when the poll will be automatically closed
        
        is_closed (:class:`bool`)
            True, if the poll is closed
        
    """

    ID: str = Field("poll", alias="@type")
    id: int
    question: str = Field(..., min_length=1, max_length=300)
    options: list[PollOption]
    total_voter_count: int
    recent_voter_user_ids: list[int]
    is_anonymous: bool
    type_: PollType = Field(..., alias='type')
    open_period: int
    close_date: int
    is_closed: bool

    @staticmethod
    def read(q: dict) -> Poll:
        return Poll.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .animation import Animation
from .audio import Audio
from .call_discard_reason import CallDiscardReason
from .chat_photo import ChatPhoto
from .contact import Contact
from .dice_stickers import DiceStickers
from .document import Document
from .encrypted_credentials import EncryptedCredentials
from .encrypted_passport_element import EncryptedPassportElement
from .formatted_text import FormattedText
from .game import Game
from .location import Location
from .message_sender import MessageSender
from .order_info import OrderInfo
from .passport_element_type import PassportElementType
from .photo import Photo
from .poll import Poll
from .sticker import Sticker
from .venue import Venue
from .video import Video
from .video_note import VideoNote
from .voice_note import VoiceNote
from .web_page import WebPage
from ..base_object import BaseObject


class MessageContent(BaseObject):
    """
    Contains the content of a message
    
    """

    ID: str = Field("messageContent", alias="@type")


class MessageAnimation(MessageContent):
    """
    An animation message (GIF-style).
    
    Params:
        animation (:class:`Animation`)
            The animation description
        
        caption (:class:`FormattedText`)
            Animation caption
        
        is_secret (:class:`bool`)
            True, if the animation thumbnail must be blurred and the animation must be shown only while tapped
        
    """

    ID: str = Field("messageAnimation", alias="@type")
    animation: Animation
    caption: FormattedText
    is_secret: bool

    @staticmethod
    def read(q: dict) -> MessageAnimation:
        return MessageAnimation.construct(**q)


class MessageAudio(MessageContent):
    """
    An audio message
    
    Params:
        audio (:class:`Audio`)
            The audio description
        
        caption (:class:`FormattedText`)
            Audio caption
        
    """

    ID: str = Field("messageAudio", alias="@type")
    audio: Audio
    caption: FormattedText

    @staticmethod
    def read(q: dict) -> MessageAudio:
        return MessageAudio.construct(**q)


class MessageBasicGroupChatCreate(MessageContent):
    """
    A newly created basic group
    
    Params:
        title (:class:`str`)
            Title of the basic group
        
        member_user_ids (:obj:`list[int]`)
            User identifiers of members in the basic group
        
    """

    ID: str = Field("messageBasicGroupChatCreate", alias="@type")
    title: str
    member_user_ids: list[int]

    @staticmethod
    def read(q: dict) -> MessageBasicGroupChatCreate:
        return MessageBasicGroupChatCreate.construct(**q)


class MessageCall(MessageContent):
    """
    A message with information about an ended call
    
    Params:
        is_video (:class:`bool`)
            True, if the call was a video call
        
        discard_reason (:class:`CallDiscardReason`)
            Reason why the call was discarded
        
        duration (:class:`int`)
            Call duration, in seconds
        
    """

    ID: str = Field("messageCall", alias="@type")
    is_video: bool
    discard_reason: CallDiscardReason
    duration: int

    @staticmethod
    def read(q: dict) -> MessageCall:
        return MessageCall.construct(**q)


class MessageChatAddMembers(MessageContent):
    """
    New chat members were added
    
    Params:
        member_user_ids (:obj:`list[int]`)
            User identifiers of the new members
        
    """

    ID: str = Field("messageChatAddMembers", alias="@type")
    member_user_ids: list[int]

    @staticmethod
    def read(q: dict) -> MessageChatAddMembers:
        return MessageChatAddMembers.construct(**q)


class MessageChatChangePhoto(MessageContent):
    """
    An updated chat photo
    
    Params:
        photo (:class:`ChatPhoto`)
            New chat photo
        
    """

    ID: str = Field("messageChatChangePhoto", alias="@type")
    photo: ChatPhoto

    @staticmethod
    def read(q: dict) -> MessageChatChangePhoto:
        return MessageChatChangePhoto.construct(**q)


class MessageChatChangeTitle(MessageContent):
    """
    An updated chat title
    
    Params:
        title (:class:`str`)
            New chat title
        
    """

    ID: str = Field("messageChatChangeTitle", alias="@type")
    title: str

    @staticmethod
    def read(q: dict) -> MessageChatChangeTitle:
        return MessageChatChangeTitle.construct(**q)


class MessageChatDeleteMember(MessageContent):
    """
    A chat member was deleted
    
    Params:
        user_id (:class:`int`)
            User identifier of the deleted chat member
        
    """

    ID: str = Field("messageChatDeleteMember", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> MessageChatDeleteMember:
        return MessageChatDeleteMember.construct(**q)


class MessageChatDeletePhoto(MessageContent):
    """
    A deleted chat photo
    
    """

    ID: str = Field("messageChatDeletePhoto", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageChatDeletePhoto:
        return MessageChatDeletePhoto.construct(**q)


class MessageChatJoinByLink(MessageContent):
    """
    A new member joined the chat by invite link
    
    """

    ID: str = Field("messageChatJoinByLink", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageChatJoinByLink:
        return MessageChatJoinByLink.construct(**q)


class MessageChatSetTtl(MessageContent):
    """
    The TTL (Time To Live) setting for messages in the chat has been changed
    
    Params:
        ttl (:class:`int`)
            New message TTL setting
        
    """

    ID: str = Field("messageChatSetTtl", alias="@type")
    ttl: int

    @staticmethod
    def read(q: dict) -> MessageChatSetTtl:
        return MessageChatSetTtl.construct(**q)


class MessageChatUpgradeFrom(MessageContent):
    """
    A supergroup has been created from a basic group
    
    Params:
        title (:class:`str`)
            Title of the newly created supergroup
        
        basic_group_id (:class:`int`)
            The identifier of the original basic group
        
    """

    ID: str = Field("messageChatUpgradeFrom", alias="@type")
    title: str
    basic_group_id: int

    @staticmethod
    def read(q: dict) -> MessageChatUpgradeFrom:
        return MessageChatUpgradeFrom.construct(**q)


class MessageChatUpgradeTo(MessageContent):
    """
    A basic group was upgraded to a supergroup and was deactivated as the result
    
    Params:
        supergroup_id (:class:`int`)
            Identifier of the supergroup to which the basic group was upgraded
        
    """

    ID: str = Field("messageChatUpgradeTo", alias="@type")
    supergroup_id: int

    @staticmethod
    def read(q: dict) -> MessageChatUpgradeTo:
        return MessageChatUpgradeTo.construct(**q)


class MessageContact(MessageContent):
    """
    A message with a user contact
    
    Params:
        contact (:class:`Contact`)
            The contact description
        
    """

    ID: str = Field("messageContact", alias="@type")
    contact: Contact

    @staticmethod
    def read(q: dict) -> MessageContact:
        return MessageContact.construct(**q)


class MessageContactRegistered(MessageContent):
    """
    A contact has registered with Telegram
    
    """

    ID: str = Field("messageContactRegistered", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageContactRegistered:
        return MessageContactRegistered.construct(**q)


class MessageCustomServiceAction(MessageContent):
    """
    A non-standard action has happened in the chat
    
    Params:
        text (:class:`str`)
            Message text to be shown in the chat
        
    """

    ID: str = Field("messageCustomServiceAction", alias="@type")
    text: str

    @staticmethod
    def read(q: dict) -> MessageCustomServiceAction:
        return MessageCustomServiceAction.construct(**q)


class MessageDice(MessageContent):
    """
    A dice message. The dice value is randomly generated by the server
    
    Params:
        initial_state (:class:`DiceStickers`)
            The animated stickers with the initial dice animation; may be null if unknown. updateMessageContent will be sent when the sticker became known
        
        final_state (:class:`DiceStickers`)
            The animated stickers with the final dice animation; may be null if unknown. updateMessageContent will be sent when the sticker became known
        
        emoji (:class:`str`)
            Emoji on which the dice throw animation is based
        
        value (:class:`int`)
            The dice value. If the value is 0, the dice don't have final state yet
        
        success_animation_frame_number (:class:`int`)
            Number of frame after which a success animation like a shower of confetti needs to be shown on updateMessageSendSucceeded
        
    """

    ID: str = Field("messageDice", alias="@type")
    initial_state: typing.Optional[DiceStickers] = None
    final_state: typing.Optional[DiceStickers] = None
    emoji: str
    value: int
    success_animation_frame_number: int

    @staticmethod
    def read(q: dict) -> MessageDice:
        return MessageDice.construct(**q)


class MessageDocument(MessageContent):
    """
    A document message (general file)
    
    Params:
        document (:class:`Document`)
            The document description
        
        caption (:class:`FormattedText`)
            Document caption
        
    """

    ID: str = Field("messageDocument", alias="@type")
    document: Document
    caption: FormattedText

    @staticmethod
    def read(q: dict) -> MessageDocument:
        return MessageDocument.construct(**q)


class MessageExpiredPhoto(MessageContent):
    """
    An expired photo message (self-destructed after TTL has elapsed)
    
    """

    ID: str = Field("messageExpiredPhoto", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageExpiredPhoto:
        return MessageExpiredPhoto.construct(**q)


class MessageExpiredVideo(MessageContent):
    """
    An expired video message (self-destructed after TTL has elapsed)
    
    """

    ID: str = Field("messageExpiredVideo", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageExpiredVideo:
        return MessageExpiredVideo.construct(**q)


class MessageGame(MessageContent):
    """
    A message with a game
    
    Params:
        game (:class:`Game`)
            The game description
        
    """

    ID: str = Field("messageGame", alias="@type")
    game: Game

    @staticmethod
    def read(q: dict) -> MessageGame:
        return MessageGame.construct(**q)


class MessageGameScore(MessageContent):
    """
    A new high score was achieved in a game
    
    Params:
        game_message_id (:class:`int`)
            Identifier of the message with the game, can be an identifier of a deleted message
        
        game_id (:class:`int`)
            Identifier of the game; may be different from the games presented in the message with the game
        
        score (:class:`int`)
            New score
        
    """

    ID: str = Field("messageGameScore", alias="@type")
    game_message_id: int
    game_id: int
    score: int

    @staticmethod
    def read(q: dict) -> MessageGameScore:
        return MessageGameScore.construct(**q)


class MessageInviteVoiceChatParticipants(MessageContent):
    """
    A message with information about an invite to a voice chat
    
    Params:
        group_call_id (:class:`int`)
            Identifier of the voice chat. The voice chat can be received through the method getGroupCall
        
        user_ids (:obj:`list[int]`)
            Invited user identifiers
        
    """

    ID: str = Field("messageInviteVoiceChatParticipants", alias="@type")
    group_call_id: int
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> MessageInviteVoiceChatParticipants:
        return MessageInviteVoiceChatParticipants.construct(**q)


class MessageInvoice(MessageContent):
    """
    A message with an invoice from a bot
    
    Params:
        title (:class:`str`)
            Product title
        
        param_description (:class:`str`)
            Product description
        
        photo (:class:`Photo`)
            Product photo; may be null
        
        currency (:class:`str`)
            Currency for the product price
        
        total_amount (:class:`int`)
            Product total price in the minimal quantity of the currency
        
        start_parameter (:class:`str`)
            Unique invoice bot start_parameter. To share an invoice use the URL https://t.me/{bot_username}?start={start_parameter}
        
        is_test (:class:`bool`)
            True, if the invoice is a test invoice
        
        need_shipping_address (:class:`bool`)
            True, if the shipping address should be specified
        
        receipt_message_id (:class:`int`)
            The identifier of the message with the receipt, after the product has been purchased
        
    """

    ID: str = Field("messageInvoice", alias="@type")
    title: str
    param_description: str
    photo: typing.Optional[Photo] = None
    currency: str
    total_amount: int
    start_parameter: str
    is_test: bool
    need_shipping_address: bool
    receipt_message_id: int

    @staticmethod
    def read(q: dict) -> MessageInvoice:
        return MessageInvoice.construct(**q)


class MessageLocation(MessageContent):
    """
    A message with a location
    
    Params:
        location (:class:`Location`)
            The location description
        
        live_period (:class:`int`)
            Time relative to the message send date, for which the location can be updated, in seconds
        
        expires_in (:class:`int`)
            Left time for which the location can be updated, in seconds. updateMessageContent is not sent when this field changes
        
        heading (:class:`int`)
            For live locations, a direction in which the location moves, in degrees; 1-360. If 0 the direction is unknown
        
        proximity_alert_radius (:class:`int`)
            For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). 0 if the notification is disabled. Available only for the message sender
        
    """

    ID: str = Field("messageLocation", alias="@type")
    location: Location
    live_period: int
    expires_in: int
    heading: int
    proximity_alert_radius: int

    @staticmethod
    def read(q: dict) -> MessageLocation:
        return MessageLocation.construct(**q)


class MessagePassportDataReceived(MessageContent):
    """
    Telegram Passport data has been received; for bots only
    
    Params:
        elements (:obj:`list[EncryptedPassportElement]`)
            List of received Telegram Passport elements
        
        credentials (:class:`EncryptedCredentials`)
            Encrypted data credentials
        
    """

    ID: str = Field("messagePassportDataReceived", alias="@type")
    elements: list[EncryptedPassportElement]
    credentials: EncryptedCredentials

    @staticmethod
    def read(q: dict) -> MessagePassportDataReceived:
        return MessagePassportDataReceived.construct(**q)


class MessagePassportDataSent(MessageContent):
    """
    Telegram Passport data has been sent
    
    Params:
        types (:obj:`list[PassportElementType]`)
            List of Telegram Passport element types sent
        
    """

    ID: str = Field("messagePassportDataSent", alias="@type")
    types: list[PassportElementType]

    @staticmethod
    def read(q: dict) -> MessagePassportDataSent:
        return MessagePassportDataSent.construct(**q)


class MessagePaymentSuccessful(MessageContent):
    """
    A payment has been completed
    
    Params:
        invoice_message_id (:class:`int`)
            Identifier of the message with the corresponding invoice; can be an identifier of a deleted message
        
        currency (:class:`str`)
            Currency for the price of the product
        
        total_amount (:class:`int`)
            Total price for the product, in the minimal quantity of the currency
        
    """

    ID: str = Field("messagePaymentSuccessful", alias="@type")
    invoice_message_id: int
    currency: str
    total_amount: int

    @staticmethod
    def read(q: dict) -> MessagePaymentSuccessful:
        return MessagePaymentSuccessful.construct(**q)


class MessagePaymentSuccessfulBot(MessageContent):
    """
    A payment has been completed; for bots only
    
    Params:
        invoice_message_id (:class:`int`)
            Identifier of the message with the corresponding invoice; can be an identifier of a deleted message
        
        currency (:class:`str`)
            Currency for price of the product
        
        total_amount (:class:`int`)
            Total price for the product, in the minimal quantity of the currency
        
        invoice_payload (:class:`str`)
            Invoice payload
        
        shipping_option_id (:class:`str`)
            Identifier of the shipping option chosen by the user; may be empty if not applicable
        
        order_info (:class:`OrderInfo`)
            Information about the order; may be null
        
        telegram_payment_charge_id (:class:`str`)
            Telegram payment identifier
        
        provider_payment_charge_id (:class:`str`)
            Provider payment identifier
        
    """

    ID: str = Field("messagePaymentSuccessfulBot", alias="@type")
    invoice_message_id: int
    currency: str
    total_amount: int
    invoice_payload: str
    shipping_option_id: str
    order_info: typing.Optional[OrderInfo] = None
    telegram_payment_charge_id: str
    provider_payment_charge_id: str

    @staticmethod
    def read(q: dict) -> MessagePaymentSuccessfulBot:
        return MessagePaymentSuccessfulBot.construct(**q)


class MessagePhoto(MessageContent):
    """
    A photo message
    
    Params:
        photo (:class:`Photo`)
            The photo description
        
        caption (:class:`FormattedText`)
            Photo caption
        
        is_secret (:class:`bool`)
            True, if the photo must be blurred and must be shown only while tapped
        
    """

    ID: str = Field("messagePhoto", alias="@type")
    photo: Photo
    caption: FormattedText
    is_secret: bool

    @staticmethod
    def read(q: dict) -> MessagePhoto:
        return MessagePhoto.construct(**q)


class MessagePinMessage(MessageContent):
    """
    A message has been pinned
    
    Params:
        message_id (:class:`int`)
            Identifier of the pinned message, can be an identifier of a deleted message or 0
        
    """

    ID: str = Field("messagePinMessage", alias="@type")
    message_id: int

    @staticmethod
    def read(q: dict) -> MessagePinMessage:
        return MessagePinMessage.construct(**q)


class MessagePoll(MessageContent):
    """
    A message with a poll
    
    Params:
        poll (:class:`Poll`)
            The poll description
        
    """

    ID: str = Field("messagePoll", alias="@type")
    poll: Poll

    @staticmethod
    def read(q: dict) -> MessagePoll:
        return MessagePoll.construct(**q)


class MessageProximityAlertTriggered(MessageContent):
    """
    A user in the chat came within proximity alert range
    
    Params:
        traveler (:class:`MessageSender`)
            The user or chat, which triggered the proximity alert
        
        watcher (:class:`MessageSender`)
            The user or chat, which subscribed for the proximity alert
        
        distance (:class:`int`)
            The distance between the users
        
    """

    ID: str = Field("messageProximityAlertTriggered", alias="@type")
    traveler: MessageSender
    watcher: MessageSender
    distance: int

    @staticmethod
    def read(q: dict) -> MessageProximityAlertTriggered:
        return MessageProximityAlertTriggered.construct(**q)


class MessageScreenshotTaken(MessageContent):
    """
    A screenshot of a message in the chat has been taken
    
    """

    ID: str = Field("messageScreenshotTaken", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageScreenshotTaken:
        return MessageScreenshotTaken.construct(**q)


class MessageSticker(MessageContent):
    """
    A sticker message
    
    Params:
        sticker (:class:`Sticker`)
            The sticker description
        
    """

    ID: str = Field("messageSticker", alias="@type")
    sticker: Sticker

    @staticmethod
    def read(q: dict) -> MessageSticker:
        return MessageSticker.construct(**q)


class MessageSupergroupChatCreate(MessageContent):
    """
    A newly created supergroup or channel
    
    Params:
        title (:class:`str`)
            Title of the supergroup or channel
        
    """

    ID: str = Field("messageSupergroupChatCreate", alias="@type")
    title: str

    @staticmethod
    def read(q: dict) -> MessageSupergroupChatCreate:
        return MessageSupergroupChatCreate.construct(**q)


class MessageText(MessageContent):
    """
    A text message
    
    Params:
        text (:class:`FormattedText`)
            Text of the message
        
        web_page (:class:`WebPage`)
            A preview of the web page that's mentioned in the text; may be null
        
    """

    ID: str = Field("messageText", alias="@type")
    text: FormattedText
    web_page: typing.Optional[WebPage] = None

    @staticmethod
    def read(q: dict) -> MessageText:
        return MessageText.construct(**q)


class MessageUnsupported(MessageContent):
    """
    Message content that is not supported in the current TDLib version
    
    """

    ID: str = Field("messageUnsupported", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageUnsupported:
        return MessageUnsupported.construct(**q)


class MessageVenue(MessageContent):
    """
    A message with information about a venue
    
    Params:
        venue (:class:`Venue`)
            The venue description
        
    """

    ID: str = Field("messageVenue", alias="@type")
    venue: Venue

    @staticmethod
    def read(q: dict) -> MessageVenue:
        return MessageVenue.construct(**q)


class MessageVideo(MessageContent):
    """
    A video message
    
    Params:
        video (:class:`Video`)
            The video description
        
        caption (:class:`FormattedText`)
            Video caption
        
        is_secret (:class:`bool`)
            True, if the video thumbnail must be blurred and the video must be shown only while tapped
        
    """

    ID: str = Field("messageVideo", alias="@type")
    video: Video
    caption: FormattedText
    is_secret: bool

    @staticmethod
    def read(q: dict) -> MessageVideo:
        return MessageVideo.construct(**q)


class MessageVideoNote(MessageContent):
    """
    A video note message
    
    Params:
        video_note (:class:`VideoNote`)
            The video note description
        
        is_viewed (:class:`bool`)
            True, if at least one of the recipients has viewed the video note
        
        is_secret (:class:`bool`)
            True, if the video note thumbnail must be blurred and the video note must be shown only while tapped
        
    """

    ID: str = Field("messageVideoNote", alias="@type")
    video_note: VideoNote
    is_viewed: bool
    is_secret: bool

    @staticmethod
    def read(q: dict) -> MessageVideoNote:
        return MessageVideoNote.construct(**q)


class MessageVoiceChatEnded(MessageContent):
    """
    A message with information about an ended voice chat
    
    Params:
        duration (:class:`int`)
            Call duration
        
    """

    ID: str = Field("messageVoiceChatEnded", alias="@type")
    duration: int

    @staticmethod
    def read(q: dict) -> MessageVoiceChatEnded:
        return MessageVoiceChatEnded.construct(**q)


class MessageVoiceChatStarted(MessageContent):
    """
    A newly created voice chat
    
    Params:
        group_call_id (:class:`int`)
            Identifier of the voice chat. The voice chat can be received through the method getGroupCall
        
    """

    ID: str = Field("messageVoiceChatStarted", alias="@type")
    group_call_id: int

    @staticmethod
    def read(q: dict) -> MessageVoiceChatStarted:
        return MessageVoiceChatStarted.construct(**q)


class MessageVoiceNote(MessageContent):
    """
    A voice note message
    
    Params:
        voice_note (:class:`VoiceNote`)
            The voice note description
        
        caption (:class:`FormattedText`)
            Voice note caption
        
        is_listened (:class:`bool`)
            True, if at least one of the recipients has listened to the voice note
        
    """

    ID: str = Field("messageVoiceNote", alias="@type")
    voice_note: VoiceNote
    caption: FormattedText
    is_listened: bool

    @staticmethod
    def read(q: dict) -> MessageVoiceNote:
        return MessageVoiceNote.construct(**q)


class MessageWebsiteConnected(MessageContent):
    """
    The current user has connected a website by logging in using Telegram Login Widget on it
    
    Params:
        domain_name (:class:`str`)
            Domain name of the connected website
        
    """

    ID: str = Field("messageWebsiteConnected", alias="@type")
    domain_name: str

    @staticmethod
    def read(q: dict) -> MessageWebsiteConnected:
        return MessageWebsiteConnected.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PageBlockVerticalAlignment(BaseObject):
    """
    Describes a Vertical alignment of a table cell content
    
    """

    ID: str = Field("pageBlockVerticalAlignment", alias="@type")


class PageBlockVerticalAlignmentBottom(PageBlockVerticalAlignment):
    """
    The content should be bottom-aligned
    
    """

    ID: str = Field("pageBlockVerticalAlignmentBottom", alias="@type")

    @staticmethod
    def read(q: dict) -> PageBlockVerticalAlignmentBottom:
        return PageBlockVerticalAlignmentBottom.construct(**q)


class PageBlockVerticalAlignmentMiddle(PageBlockVerticalAlignment):
    """
    The content should be middle-aligned
    
    """

    ID: str = Field("pageBlockVerticalAlignmentMiddle", alias="@type")

    @staticmethod
    def read(q: dict) -> PageBlockVerticalAlignmentMiddle:
        return PageBlockVerticalAlignmentMiddle.construct(**q)


class PageBlockVerticalAlignmentTop(PageBlockVerticalAlignment):
    """
    The content should be top-aligned
    
    """

    ID: str = Field("pageBlockVerticalAlignmentTop", alias="@type")

    @staticmethod
    def read(q: dict) -> PageBlockVerticalAlignmentTop:
        return PageBlockVerticalAlignmentTop.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import CallProblem


class SendCallRating(BaseObject):
    """
    Sends a call rating
    
    Params:
        call_id (:class:`int`)
            Call identifier
        
        rating (:class:`int`)
            Call rating; 1-5
        
        comment (:class:`str`)
            An optional user comment if the rating is less than 5
        
        problems (:obj:`list[CallProblem]`)
            List of the exact types of problems with the call, specified by the user
        
    """

    ID: str = Field("sendCallRating", alias="@type")
    call_id: int
    rating: int
    comment: str
    problems: list[CallProblem]

    @staticmethod
    def read(q: dict) -> SendCallRating:
        return SendCallRating.construct(**q)



import re


def upper_first(s: str):
    return s[:1].upper() + s[1:]


def lower_first(s: str):
    return s[:1].lower() + s[1:]


def snake_case(s: str):
    if not str:
        return ""

    s = re.sub(r'(.)([A-Z][a-z]+)', r'\1_\2', s)
    return re.sub(r'([a-z0-9])([A-Z])', r'\1_\2', s).lower()



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .storage_statistics_by_chat import StorageStatisticsByChat
from ..base_object import BaseObject


class StorageStatistics(BaseObject):
    """
    Contains the exact storage usage statistics split by chats and file type
    
    Params:
        size (:class:`int`)
            Total size of files
        
        count (:class:`int`)
            Total number of files
        
        by_chat (:obj:`list[StorageStatisticsByChat]`)
            Statistics split by chats
        
    """

    ID: str = Field("storageStatistics", alias="@type")
    size: int
    count: int
    by_chat: list[StorageStatisticsByChat]

    @staticmethod
    def read(q: dict) -> StorageStatistics:
        return StorageStatistics.construct(**q)



from __future__ import annotations

import asyncio
from collections.abc import Callable
from typing import Any, Coroutine, Optional, TypeVar

from .api import BaseObject
from .filters import FilterCallable

SomeUpdate = TypeVar('SomeUpdate', bound=BaseObject)
HandlerCallable = Callable[['aiotdlib.Client', SomeUpdate], Coroutine[Any, Any, None]]


class Handler(object):
    def __init__(self, function: HandlerCallable, *, filters: FilterCallable = None):
        if not asyncio.iscoroutinefunction(function):
            raise ValueError('function should be async callable!')

        if filters is not None and not asyncio.iscoroutinefunction(filters):
            raise ValueError('filters should be async callable!')

        self.function: HandlerCallable = function
        self.filters: Optional[FilterCallable] = filters

    async def __call__(self, client: 'Client', update: BaseObject):
        if callable(self.filters):
            filter_result = await self.filters(update)

            if not filter_result:
                return

        return await self.function(client, update)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetMessageLinkInfo(BaseObject):
    """
    Returns information about a public or private message link
    
    Params:
        url (:class:`str`)
            The message link in the format "https://t.me/c/...", or "tg://privatepost?...", or "https://t.me/username/...", or "tg://resolve?..."
        
    """

    ID: str = Field("getMessageLinkInfo", alias="@type")
    url: str

    @staticmethod
    def read(q: dict) -> GetMessageLinkInfo:
        return GetMessageLinkInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import FileType, InputFile


class UploadFile(BaseObject):
    """
    Asynchronously uploads a file to the cloud without sending it in a message. updateFile will be used to notify about upload progress and successful completion of the upload. The file will not have a persistent remote identifier until it will be sent in a message
    
    Params:
        file (:class:`InputFile`)
            File to upload
        
        file_type (:class:`FileType`)
            File type
        
        priority (:class:`int`)
            Priority of the upload (1-32). The higher the priority, the earlier the file will be uploaded. If the priorities of two files are equal, then the first one for which uploadFile was called will be uploaded first
        
    """

    ID: str = Field("uploadFile", alias="@type")
    file: InputFile
    file_type: FileType
    priority: int

    @staticmethod
    def read(q: dict) -> UploadFile:
        return UploadFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Minithumbnail(BaseObject):
    """
    Thumbnail image of a very poor quality and low resolution
    
    Params:
        width (:class:`int`)
            Thumbnail width, usually doesn't exceed 40
        
        height (:class:`int`)
            Thumbnail height, usually doesn't exceed 40
        
        data (:class:`str`)
            The thumbnail in JPEG format
        
    """

    ID: str = Field("minithumbnail", alias="@type")
    width: int
    height: int
    data: str

    @staticmethod
    def read(q: dict) -> Minithumbnail:
        return Minithumbnail.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .session import Session
from ..base_object import BaseObject


class Sessions(BaseObject):
    """
    Contains a list of sessions
    
    Params:
        sessions (:obj:`list[Session]`)
            List of sessions
        
    """

    ID: str = Field("sessions", alias="@type")
    sessions: list[Session]

    @staticmethod
    def read(q: dict) -> Sessions:
        return Sessions.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetPollAnswer(BaseObject):
    """
    Changes the user answer to a poll. A poll in quiz mode can be answered only once
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to which the poll belongs
        
        message_id (:class:`int`)
            Identifier of the message containing the poll
        
        option_ids (:obj:`list[int]`)
            0-based identifiers of answer options, chosen by the user. User can choose more than 1 answer option only is the poll allows multiple answers
        
    """

    ID: str = Field("setPollAnswer", alias="@type")
    chat_id: int
    message_id: int
    option_ids: list[int]

    @staticmethod
    def read(q: dict) -> SetPollAnswer:
        return SetPollAnswer.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CallProtocol(BaseObject):
    """
    Specifies the supported call protocols
    
    Params:
        udp_p2p (:class:`bool`)
            True, if UDP peer-to-peer connections are supported
        
        udp_reflector (:class:`bool`)
            True, if connection through UDP reflectors is supported
        
        min_layer (:class:`int`)
            The minimum supported API layer; use 65
        
        max_layer (:class:`int`)
            The maximum supported API layer; use 65
        
        library_versions (:obj:`list[str]`)
            List of supported tgcalls versions
        
    """

    ID: str = Field("callProtocol", alias="@type")
    udp_p2p: bool
    udp_reflector: bool
    min_layer: int
    max_layer: int
    library_versions: list[str]

    @staticmethod
    def read(q: dict) -> CallProtocol:
        return CallProtocol.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputSticker


class CreateNewStickerSet(BaseObject):
    """
    Creates a new sticker set; for bots only. Returns the newly created sticker set
    
    Params:
        user_id (:class:`int`)
            Sticker set owner
        
        title (:class:`str`)
            Sticker set title; 1-64 characters
        
        name (:class:`str`)
            Sticker set name. Can contain only English letters, digits and underscores. Must end with *"_by_<bot username>"* (*<bot_username>* is case insensitive); 1-64 characters
        
        is_masks (:class:`bool`)
            True, if stickers are masks. Animated stickers can't be masks
        
        stickers (:obj:`list[InputSticker]`)
            List of stickers to be added to the set; must be non-empty. All stickers must be of the same type
        
    """

    ID: str = Field("createNewStickerSet", alias="@type")
    user_id: int
    title: str = Field(..., min_length=1, max_length=64)
    name: str = Field(..., min_length=1, max_length=64)
    is_masks: bool
    stickers: list[InputSticker]

    @staticmethod
    def read(q: dict) -> CreateNewStickerSet:
        return CreateNewStickerSet.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Location


class GetMapThumbnailFile(BaseObject):
    """
    Returns information about a file with a map thumbnail in PNG format. Only map thumbnail files with size less than 1MB can be downloaded
    
    Params:
        location (:class:`Location`)
            Location of the map center
        
        zoom (:class:`int`)
            Map zoom level; 13-20
        
        width (:class:`int`)
            Map width in pixels before applying scale; 16-1024
        
        height (:class:`int`)
            Map height in pixels before applying scale; 16-1024
        
        scale (:class:`int`)
            Map scale; 1-3
        
        chat_id (:class:`int`)
            Identifier of a chat, in which the thumbnail will be shown. Use 0 if unknown
        
    """

    ID: str = Field("getMapThumbnailFile", alias="@type")
    location: Location
    zoom: int
    width: int
    height: int
    scale: int
    chat_id: int

    @staticmethod
    def read(q: dict) -> GetMapThumbnailFile:
        return GetMapThumbnailFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .passport_element import PassportElement
from ..base_object import BaseObject


class PassportElements(BaseObject):
    """
    Contains information about saved Telegram Passport elements
    
    Params:
        elements (:obj:`list[PassportElement]`)
            Telegram Passport elements
        
    """

    ID: str = Field("passportElements", alias="@type")
    elements: list[PassportElement]

    @staticmethod
    def read(q: dict) -> PassportElements:
        return PassportElements.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SendEmailAddressVerificationCode(BaseObject):
    """
    Sends a code to verify an email address to be added to a user's Telegram Passport
    
    Params:
        email_address (:class:`str`)
            Email address
        
    """

    ID: str = Field("sendEmailAddressVerificationCode", alias="@type")
    email_address: str

    @staticmethod
    def read(q: dict) -> SendEmailAddressVerificationCode:
        return SendEmailAddressVerificationCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SavedCredentials(BaseObject):
    """
    Contains information about saved card credentials
    
    Params:
        id (:class:`str`)
            Unique identifier of the saved credentials
        
        title (:class:`str`)
            Title of the saved credentials
        
    """

    ID: str = Field("savedCredentials", alias="@type")
    id: str
    title: str

    @staticmethod
    def read(q: dict) -> SavedCredentials:
        return SavedCredentials.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import NetworkType


class SetNetworkType(BaseObject):
    """
    Sets the current network type. Can be called before authorization. Calling this method forces all network connections to reopen, mitigating the delay in switching between different networks, so it should be called whenever the network is changed, even if the network type remains the same. Network type is used to check whether the library can use the network at all and also for collecting detailed network data usage statistics
    
    Params:
        type_ (:class:`NetworkType`)
            The new network type. By default, networkTypeOther
        
    """

    ID: str = Field("setNetworkType", alias="@type")
    type_: NetworkType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> SetNetworkType:
        return SetNetworkType.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class AddFavoriteSticker(BaseObject):
    """
    Adds a new sticker to the list of favorite stickers. The new sticker is added to the top of the list. If the sticker was already in the list, it is removed from the list first. Only stickers belonging to a sticker set can be added to this list
    
    Params:
        sticker (:class:`InputFile`)
            Sticker file to add
        
    """

    ID: str = Field("addFavoriteSticker", alias="@type")
    sticker: InputFile

    @staticmethod
    def read(q: dict) -> AddFavoriteSticker:
        return AddFavoriteSticker.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RemoveContacts(BaseObject):
    """
    Removes users from the contact list
    
    Params:
        user_ids (:obj:`list[int]`)
            Identifiers of users to be deleted
        
    """

    ID: str = Field("removeContacts", alias="@type")
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> RemoveContacts:
        return RemoveContacts.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchContacts(BaseObject):
    """
    Searches for the specified query in the first names, last names and usernames of the known user contacts
    
    Params:
        query (:class:`str`)
            Query to search for; may be empty to return all contacts
        
        limit (:class:`int`)
            The maximum number of users to be returned
        
    """

    ID: str = Field("searchContacts", alias="@type")
    query: str
    limit: int

    @staticmethod
    def read(q: dict) -> SearchContacts:
        return SearchContacts.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ClearAllDraftMessages(BaseObject):
    """
    Clears draft messages in all chats
    
    Params:
        exclude_secret_chats (:class:`bool`)
            If true, local draft messages in secret chats will not be cleared
        
    """

    ID: str = Field("clearAllDraftMessages", alias="@type")
    exclude_secret_chats: bool

    @staticmethod
    def read(q: dict) -> ClearAllDraftMessages:
        return ClearAllDraftMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ProxyType(BaseObject):
    """
    Describes the type of a proxy server
    
    """

    ID: str = Field("proxyType", alias="@type")


class ProxyTypeHttp(ProxyType):
    """
    A HTTP transparent proxy server
    
    Params:
        username (:class:`str`)
            Username for logging in; may be empty
        
        password (:class:`str`)
            Password for logging in; may be empty
        
        http_only (:class:`bool`)
            Pass true if the proxy supports only HTTP requests and doesn't support transparent TCP connections via HTTP CONNECT method
        
    """

    ID: str = Field("proxyTypeHttp", alias="@type")
    username: str
    password: str
    http_only: bool

    @staticmethod
    def read(q: dict) -> ProxyTypeHttp:
        return ProxyTypeHttp.construct(**q)


class ProxyTypeMtproto(ProxyType):
    """
    An MTProto proxy server
    
    Params:
        secret (:class:`str`)
            The proxy's secret in hexadecimal encoding
        
    """

    ID: str = Field("proxyTypeMtproto", alias="@type")
    secret: str

    @staticmethod
    def read(q: dict) -> ProxyTypeMtproto:
        return ProxyTypeMtproto.construct(**q)


class ProxyTypeSocks5(ProxyType):
    """
    A SOCKS5 proxy server
    
    Params:
        username (:class:`str`)
            Username for logging in; may be empty
        
        password (:class:`str`)
            Password for logging in; may be empty
        
    """

    ID: str = Field("proxyTypeSocks5", alias="@type")
    username: str
    password: str

    @staticmethod
    def read(q: dict) -> ProxyTypeSocks5:
        return ProxyTypeSocks5.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatMembersFilter


class SearchChatMembers(BaseObject):
    """
    Searches for a specified query in the first name, last name and username of the members of a specified chat. Requires administrator rights in channels
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        query (:class:`str`)
            Query to search for
        
        limit (:class:`int`)
            The maximum number of users to be returned
        
        filter_ (:class:`ChatMembersFilter`)
            The type of users to return. By default, chatMembersFilterMembers
        
    """

    ID: str = Field("searchChatMembers", alias="@type")
    chat_id: int
    query: str
    limit: int
    filter_: ChatMembersFilter = Field(..., alias='filter')

    @staticmethod
    def read(q: dict) -> SearchChatMembers:
        return SearchChatMembers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetChatClientData(BaseObject):
    """
    Changes application-specific data associated with a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        client_data (:class:`str`)
            New value of client_data
        
    """

    ID: str = Field("setChatClientData", alias="@type")
    chat_id: int
    client_data: str

    @staticmethod
    def read(q: dict) -> SetChatClientData:
        return SetChatClientData.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ReplyMarkup


class EditMessageReplyMarkup(BaseObject):
    """
    Edits the message reply markup; for bots only. Returns the edited message after the edit is completed on the server side
    
    Params:
        chat_id (:class:`int`)
            The chat the message belongs to
        
        message_id (:class:`int`)
            Identifier of the message
        
        reply_markup (:class:`ReplyMarkup`)
            The new message reply markup
        
    """

    ID: str = Field("editMessageReplyMarkup", alias="@type")
    chat_id: int
    message_id: int
    reply_markup: ReplyMarkup

    @staticmethod
    def read(q: dict) -> EditMessageReplyMarkup:
        return EditMessageReplyMarkup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .page_block import PageBlock
from ..base_object import BaseObject


class WebPageInstantView(BaseObject):
    """
    Describes an instant view page for a web page
    
    Params:
        page_blocks (:obj:`list[PageBlock]`)
            Content of the web page
        
        view_count (:class:`int`)
            Number of the instant view views; 0 if unknown
        
        version (:class:`int`)
            Version of the instant view, currently can be 1 or 2
        
        is_rtl (:class:`bool`)
            True, if the instant view must be shown from right to left
        
        is_full (:class:`bool`)
            True, if the instant view contains the full page. A network request might be needed to get the full web page instant view
        
    """

    ID: str = Field("webPageInstantView", alias="@type")
    page_blocks: list[PageBlock]
    view_count: int
    version: int
    is_rtl: bool
    is_full: bool

    @staticmethod
    def read(q: dict) -> WebPageInstantView:
        return WebPageInstantView.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatInviteLinkCount(BaseObject):
    """
    Describes a chat administrator with a number of active and revoked chat invite links
    
    Params:
        user_id (:class:`int`)
            Administrator's user identifier
        
        invite_link_count (:class:`int`)
            Number of active invite links
        
        revoked_invite_link_count (:class:`int`)
            Number of revoked invite links
        
    """

    ID: str = Field("chatInviteLinkCount", alias="@type")
    user_id: int
    invite_link_count: int
    revoked_invite_link_count: int

    @staticmethod
    def read(q: dict) -> ChatInviteLinkCount:
        return ChatInviteLinkCount.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class UserPrivacySettingRule(BaseObject):
    """
    Represents a single rule for managing privacy settings
    
    """

    ID: str = Field("userPrivacySettingRule", alias="@type")


class UserPrivacySettingRuleAllowAll(UserPrivacySettingRule):
    """
    A rule to allow all users to do something
    
    """

    ID: str = Field("userPrivacySettingRuleAllowAll", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleAllowAll:
        return UserPrivacySettingRuleAllowAll.construct(**q)


class UserPrivacySettingRuleAllowChatMembers(UserPrivacySettingRule):
    """
    A rule to allow all members of certain specified basic groups and supergroups to doing something
    
    Params:
        chat_ids (:obj:`list[int]`)
            The chat identifiers, total number of chats in all rules must not exceed 20
        
    """

    ID: str = Field("userPrivacySettingRuleAllowChatMembers", alias="@type")
    chat_ids: list[int]

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleAllowChatMembers:
        return UserPrivacySettingRuleAllowChatMembers.construct(**q)


class UserPrivacySettingRuleAllowContacts(UserPrivacySettingRule):
    """
    A rule to allow all of a user's contacts to do something
    
    """

    ID: str = Field("userPrivacySettingRuleAllowContacts", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleAllowContacts:
        return UserPrivacySettingRuleAllowContacts.construct(**q)


class UserPrivacySettingRuleAllowUsers(UserPrivacySettingRule):
    """
    A rule to allow certain specified users to do something
    
    Params:
        user_ids (:obj:`list[int]`)
            The user identifiers, total number of users in all rules must not exceed 1000
        
    """

    ID: str = Field("userPrivacySettingRuleAllowUsers", alias="@type")
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleAllowUsers:
        return UserPrivacySettingRuleAllowUsers.construct(**q)


class UserPrivacySettingRuleRestrictAll(UserPrivacySettingRule):
    """
    A rule to restrict all users from doing something
    
    """

    ID: str = Field("userPrivacySettingRuleRestrictAll", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleRestrictAll:
        return UserPrivacySettingRuleRestrictAll.construct(**q)


class UserPrivacySettingRuleRestrictChatMembers(UserPrivacySettingRule):
    """
    A rule to restrict all members of specified basic groups and supergroups from doing something
    
    Params:
        chat_ids (:obj:`list[int]`)
            The chat identifiers, total number of chats in all rules must not exceed 20
        
    """

    ID: str = Field("userPrivacySettingRuleRestrictChatMembers", alias="@type")
    chat_ids: list[int]

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleRestrictChatMembers:
        return UserPrivacySettingRuleRestrictChatMembers.construct(**q)


class UserPrivacySettingRuleRestrictContacts(UserPrivacySettingRule):
    """
    A rule to restrict all contacts of a user from doing something
    
    """

    ID: str = Field("userPrivacySettingRuleRestrictContacts", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleRestrictContacts:
        return UserPrivacySettingRuleRestrictContacts.construct(**q)


class UserPrivacySettingRuleRestrictUsers(UserPrivacySettingRule):
    """
    A rule to restrict all specified users from doing something
    
    Params:
        user_ids (:obj:`list[int]`)
            The user identifiers, total number of users in all rules must not exceed 1000
        
    """

    ID: str = Field("userPrivacySettingRuleRestrictUsers", alias="@type")
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> UserPrivacySettingRuleRestrictUsers:
        return UserPrivacySettingRuleRestrictUsers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputInlineQueryResult


class AnswerInlineQuery(BaseObject):
    """
    Sets the result of an inline query; for bots only
    
    Params:
        inline_query_id (:class:`int`)
            Identifier of the inline query
        
        is_personal (:class:`bool`)
            True, if the result of the query can be cached for the specified user
        
        results (:obj:`list[InputInlineQueryResult]`)
            The results of the query
        
        cache_time (:class:`int`)
            Allowed time to cache the results of the query, in seconds
        
        next_offset (:class:`str`)
            Offset for the next inline query; pass an empty string if there are no more results
        
        switch_pm_text (:class:`str`)
            If non-empty, this text should be shown on the button that opens a private chat with the bot and sends a start message to the bot with the parameter switch_pm_parameter
        
        switch_pm_parameter (:class:`str`)
            The parameter for the bot start message
        
    """

    ID: str = Field("answerInlineQuery", alias="@type")
    inline_query_id: int
    is_personal: bool
    results: list[InputInlineQueryResult]
    cache_time: int
    next_offset: str
    switch_pm_text: str
    switch_pm_parameter: str

    @staticmethod
    def read(q: dict) -> AnswerInlineQuery:
        return AnswerInlineQuery.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ToggleSupergroupIsAllHistoryAvailable(BaseObject):
    """
    Toggles whether the message history of a supergroup is available to new members; requires can_change_info administrator right
    
    Params:
        supergroup_id (:class:`int`)
            The identifier of the supergroup
        
        is_all_history_available (:class:`bool`)
            The new value of is_all_history_available
        
    """

    ID: str = Field("toggleSupergroupIsAllHistoryAvailable", alias="@type")
    supergroup_id: int
    is_all_history_available: bool

    @staticmethod
    def read(q: dict) -> ToggleSupergroupIsAllHistoryAvailable:
        return ToggleSupergroupIsAllHistoryAvailable.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .group_call_join_response_candidate import GroupCallJoinResponseCandidate
from .group_call_payload import GroupCallPayload
from ..base_object import BaseObject


class GroupCallJoinResponse(BaseObject):
    """
    Describes a group call join response
    
    """

    ID: str = Field("groupCallJoinResponse", alias="@type")


class GroupCallJoinResponseStream(GroupCallJoinResponse):
    """
    Describes that group call needs to be joined as a stream
    
    """

    ID: str = Field("groupCallJoinResponseStream", alias="@type")

    @staticmethod
    def read(q: dict) -> GroupCallJoinResponseStream:
        return GroupCallJoinResponseStream.construct(**q)


class GroupCallJoinResponseWebrtc(GroupCallJoinResponse):
    """
    Contains data needed to join the group call with WebRTC
    
    Params:
        payload (:class:`GroupCallPayload`)
            Group call payload to pass to tgcalls
        
        candidates (:obj:`list[GroupCallJoinResponseCandidate]`)
            Join response candidates to pass to tgcalls
        
    """

    ID: str = Field("groupCallJoinResponseWebrtc", alias="@type")
    payload: GroupCallPayload
    candidates: list[GroupCallJoinResponseCandidate]

    @staticmethod
    def read(q: dict) -> GroupCallJoinResponseWebrtc:
        return GroupCallJoinResponseWebrtc.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .group_call_recent_speaker import GroupCallRecentSpeaker
from ..base_object import BaseObject


class GroupCall(BaseObject):
    """
    Describes a group call
    
    Params:
        id (:class:`int`)
            Group call identifier
        
        title (:class:`str`)
            Group call title
        
        is_active (:class:`bool`)
            True, if the call is active
        
        is_joined (:class:`bool`)
            True, if the call is joined
        
        need_rejoin (:class:`bool`)
            True, if user was kicked from the call because of network loss and the call needs to be rejoined
        
        can_unmute_self (:class:`bool`)
            True, if the current user can unmute themself
        
        can_be_managed (:class:`bool`)
            True, if the current user can manage the group call
        
        participant_count (:class:`int`)
            Number of participants in the group call
        
        loaded_all_participants (:class:`bool`)
            True, if all group call participants are loaded
        
        recent_speakers (:obj:`list[GroupCallRecentSpeaker]`)
            Recently speaking users in the group call
        
        mute_new_participants (:class:`bool`)
            True, if only group call administrators can unmute new participants
        
        can_change_mute_new_participants (:class:`bool`)
            True, if the current user can enable or disable mute_new_participants setting
        
        record_duration (:class:`int`)
            Duration of the ongoing group call recording, in seconds; 0 if none. An updateGroupCall update is not triggered when value of this field changes, but the same recording goes on
        
        duration (:class:`int`)
            Call duration; for ended calls only
        
    """

    ID: str = Field("groupCall", alias="@type")
    id: int
    title: str
    is_active: bool
    is_joined: bool
    need_rejoin: bool
    can_unmute_self: bool
    can_be_managed: bool
    participant_count: int
    loaded_all_participants: bool
    recent_speakers: list[GroupCallRecentSpeaker]
    mute_new_participants: bool
    can_change_mute_new_participants: bool
    record_duration: int
    duration: int

    @staticmethod
    def read(q: dict) -> GroupCall:
        return GroupCall.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class FilePart(BaseObject):
    """
    Contains a part of a file
    
    Params:
        data (:class:`str`)
            File bytes
        
    """

    ID: str = Field("filePart", alias="@type")
    data: str

    @staticmethod
    def read(q: dict) -> FilePart:
        return FilePart.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatNotificationSettings(BaseObject):
    """
    Contains information about notification settings for a chat
    
    Params:
        use_default_mute_for (:class:`bool`)
            If true, mute_for is ignored and the value for the relevant type of chat is used instead
        
        mute_for (:class:`int`)
            Time left before notifications will be unmuted, in seconds
        
        use_default_sound (:class:`bool`)
            If true, sound is ignored and the value for the relevant type of chat is used instead
        
        sound (:class:`str`)
            The name of an audio file to be used for notification sounds; only applies to iOS applications
        
        use_default_show_preview (:class:`bool`)
            If true, show_preview is ignored and the value for the relevant type of chat is used instead
        
        show_preview (:class:`bool`)
            True, if message content should be displayed in notifications
        
        use_default_disable_pinned_message_notifications (:class:`bool`)
            If true, disable_pinned_message_notifications is ignored and the value for the relevant type of chat is used instead
        
        disable_pinned_message_notifications (:class:`bool`)
            If true, notifications for incoming pinned messages will be created as for an ordinary unread message
        
        use_default_disable_mention_notifications (:class:`bool`)
            If true, disable_mention_notifications is ignored and the value for the relevant type of chat is used instead
        
        disable_mention_notifications (:class:`bool`)
            If true, notifications for messages with mentions will be created as for an ordinary unread message
        
    """

    ID: str = Field("chatNotificationSettings", alias="@type")
    use_default_mute_for: bool
    mute_for: int
    use_default_sound: bool
    sound: str
    use_default_show_preview: bool
    show_preview: bool
    use_default_disable_pinned_message_notifications: bool
    disable_pinned_message_notifications: bool
    use_default_disable_mention_notifications: bool
    disable_mention_notifications: bool

    @staticmethod
    def read(q: dict) -> ChatNotificationSettings:
        return ChatNotificationSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchPublicChat(BaseObject):
    """
    Searches a public chat by its username. Currently only private chats, supergroups and channels can be public. Returns the chat if found; otherwise an error is returned
    
    Params:
        username (:class:`str`)
            Username to be resolved
        
    """

    ID: str = Field("searchPublicChat", alias="@type")
    username: str

    @staticmethod
    def read(q: dict) -> SearchPublicChat:
        return SearchPublicChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class WriteGeneratedFilePart(BaseObject):
    """
    Writes a part of a generated file. This method is intended to be used only if the application has no direct access to TDLib's file system, because it is usually slower than a direct write to the destination file
    
    Params:
        generation_id (:class:`int`)
            The identifier of the generation process
        
        offset (:class:`int`)
            The offset from which to write the data to the file
        
        data (:class:`str`)
            The data to write
        
    """

    ID: str = Field("writeGeneratedFilePart", alias="@type")
    generation_id: int
    offset: int
    data: str

    @staticmethod
    def read(q: dict) -> WriteGeneratedFilePart:
        return WriteGeneratedFilePart.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetRecoveryEmailAddress(BaseObject):
    """
    Returns a 2-step verification recovery email address that was previously set up. This method can be used to verify a password provided by the user
    
    Params:
        password (:class:`str`)
            The password for the current user
        
    """

    ID: str = Field("getRecoveryEmailAddress", alias="@type")
    password: str

    @staticmethod
    def read(q: dict) -> GetRecoveryEmailAddress:
        return GetRecoveryEmailAddress.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PaymentsProviderStripe(BaseObject):
    """
    Stripe payment provider
    
    Params:
        publishable_key (:class:`str`)
            Stripe API publishable key
        
        need_country (:class:`bool`)
            True, if the user country must be provided
        
        need_postal_code (:class:`bool`)
            True, if the user ZIP/postal code must be provided
        
        need_cardholder_name (:class:`bool`)
            True, if the cardholder name must be provided
        
    """

    ID: str = Field("paymentsProviderStripe", alias="@type")
    publishable_key: str
    need_country: bool
    need_postal_code: bool
    need_cardholder_name: bool

    @staticmethod
    def read(q: dict) -> PaymentsProviderStripe:
        return PaymentsProviderStripe.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file import File
from ..base_object import BaseObject


class AnimatedChatPhoto(BaseObject):
    """
    Animated variant of a chat photo in MPEG4 format
    
    Params:
        length (:class:`int`)
            Animation width and height
        
        file (:class:`File`)
            Information about the animation file
        
        main_frame_timestamp (:class:`float`)
            Timestamp of the frame, used as a static chat photo
        
    """

    ID: str = Field("animatedChatPhoto", alias="@type")
    length: int
    file: File
    main_frame_timestamp: float

    @staticmethod
    def read(q: dict) -> AnimatedChatPhoto:
        return AnimatedChatPhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .country_info import CountryInfo
from ..base_object import BaseObject


class PhoneNumberInfo(BaseObject):
    """
    Contains information about a phone number
    
    Params:
        country (:class:`CountryInfo`)
            Information about the country to which the phone number belongs; may be null
        
        country_calling_code (:class:`str`)
            The part of the phone number denoting country calling code or its part
        
        formatted_phone_number (:class:`str`)
            The phone number without country calling code formatted accordingly to local rules
        
    """

    ID: str = Field("phoneNumberInfo", alias="@type")
    country: typing.Optional[CountryInfo] = None
    country_calling_code: str
    formatted_phone_number: str

    @staticmethod
    def read(q: dict) -> PhoneNumberInfo:
        return PhoneNumberInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_invite_link_member import ChatInviteLinkMember
from ..base_object import BaseObject


class ChatInviteLinkMembers(BaseObject):
    """
    Contains a list of chat members joined a chat by an invite link
    
    Params:
        total_count (:class:`int`)
            Approximate total count of chat members found
        
        members (:obj:`list[ChatInviteLinkMember]`)
            List of chat members, joined a chat by an invite link
        
    """

    ID: str = Field("chatInviteLinkMembers", alias="@type")
    total_count: int
    members: list[ChatInviteLinkMember]

    @staticmethod
    def read(q: dict) -> ChatInviteLinkMembers:
        return ChatInviteLinkMembers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import FileType


class GetRemoteFile(BaseObject):
    """
    Returns information about a file by its remote ID; this is an offline request. Can be used to register a URL as a file for further uploading, or sending as a message. Even the request succeeds, the file can be used only if it is still accessible to the user. For example, if the file is from a message, then the message must be not deleted and accessible to the user. If the file database is disabled, then the corresponding object with the file must be preloaded by the application
    
    Params:
        remote_file_id (:class:`str`)
            Remote identifier of the file to get
        
        file_type (:class:`FileType`)
            File type, if known
        
    """

    ID: str = Field("getRemoteFile", alias="@type")
    remote_file_id: str
    file_type: FileType

    @staticmethod
    def read(q: dict) -> GetRemoteFile:
        return GetRemoteFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DownloadFile(BaseObject):
    """
    Downloads a file from the cloud. Download progress and completion of the download will be notified through updateFile updates
    
    Params:
        file_id (:class:`int`)
            Identifier of the file to download
        
        priority (:class:`int`)
            Priority of the download (1-32). The higher the priority, the earlier the file will be downloaded. If the priorities of two files are equal, then the last one for which downloadFile was called will be downloaded first
        
        offset (:class:`int`)
            The starting position from which the file should be downloaded
        
        limit (:class:`int`)
            Number of bytes which should be downloaded starting from the "offset" position before the download will be automatically cancelled; use 0 to download without a limit
        
        synchronous (:class:`bool`)
            If false, this request returns file state just after the download has been started. If true, this request returns file state only after the download has succeeded, has failed, has been cancelled or a new downloadFile request with different offset/limit parameters was sent
        
    """

    ID: str = Field("downloadFile", alias="@type")
    file_id: int
    priority: int
    offset: int
    limit: int
    synchronous: bool

    @staticmethod
    def read(q: dict) -> DownloadFile:
        return DownloadFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .message import Message
from ..base_object import BaseObject


class MessageLinkInfo(BaseObject):
    """
    Contains information about a link to a message in a chat
    
    Params:
        is_public (:class:`bool`)
            True, if the link is a public link for a message in a chat
        
        chat_id (:class:`int`)
            If found, identifier of the chat to which the message belongs, 0 otherwise
        
        message (:class:`Message`)
            If found, the linked message; may be null
        
        for_album (:class:`bool`)
            True, if the whole media album to which the message belongs is linked
        
        for_comment (:class:`bool`)
            True, if the message is linked as a channel post comment or from a message thread
        
    """

    ID: str = Field("messageLinkInfo", alias="@type")
    is_public: bool
    chat_id: int
    message: typing.Optional[Message] = None
    for_album: bool
    for_comment: bool

    @staticmethod
    def read(q: dict) -> MessageLinkInfo:
        return MessageLinkInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class UserType(BaseObject):
    """
    Represents the type of a user. The following types are possible: regular users, deleted users and bots
    
    """

    ID: str = Field("userType", alias="@type")


class UserTypeBot(UserType):
    """
    A bot (see https://core.telegram.org/bots)
    
    Params:
        can_join_groups (:class:`bool`)
            True, if the bot can be invited to basic group and supergroup chats
        
        can_read_all_group_messages (:class:`bool`)
            True, if the bot can read all messages in basic group or supergroup chats and not just those addressed to the bot. In private and channel chats a bot can always read all messages
        
        is_inline (:class:`bool`)
            True, if the bot supports inline queries
        
        inline_query_placeholder (:class:`str`)
            Placeholder for inline queries (displayed on the application input field)
        
        need_location (:class:`bool`)
            True, if the location of the user should be sent with every inline query to this bot
        
    """

    ID: str = Field("userTypeBot", alias="@type")
    can_join_groups: bool
    can_read_all_group_messages: bool
    is_inline: bool
    inline_query_placeholder: str
    need_location: bool

    @staticmethod
    def read(q: dict) -> UserTypeBot:
        return UserTypeBot.construct(**q)


class UserTypeDeleted(UserType):
    """
    A deleted user or deleted bot. No information on the user besides the user identifier is available. It is not possible to perform any active actions on this type of user
    
    """

    ID: str = Field("userTypeDeleted", alias="@type")

    @staticmethod
    def read(q: dict) -> UserTypeDeleted:
        return UserTypeDeleted.construct(**q)


class UserTypeRegular(UserType):
    """
    A regular user
    
    """

    ID: str = Field("userTypeRegular", alias="@type")

    @staticmethod
    def read(q: dict) -> UserTypeRegular:
        return UserTypeRegular.construct(**q)


class UserTypeUnknown(UserType):
    """
    No information on the user besides the user identifier is available, yet this user has not been deleted. This object is extremely rare and must be handled like a deleted user. It is not possible to perform any actions on users of this type
    
    """

    ID: str = Field("userTypeUnknown", alias="@type")

    @staticmethod
    def read(q: dict) -> UserTypeUnknown:
        return UserTypeUnknown.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LabeledPricePart(BaseObject):
    """
    Portion of the price of a product (e.g., "delivery cost", "tax amount")
    
    Params:
        label (:class:`str`)
            Label for this portion of the product price
        
        amount (:class:`int`)
            Currency amount in minimal quantity of the currency
        
    """

    ID: str = Field("labeledPricePart", alias="@type")
    label: str
    amount: int

    @staticmethod
    def read(q: dict) -> LabeledPricePart:
        return LabeledPricePart.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteChatHistory(BaseObject):
    """
    Deletes all messages in the chat. Use Chat.can_be_deleted_only_for_self and Chat.can_be_deleted_for_all_users fields to find whether and how the method can be applied to the chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        remove_from_chat_list (:class:`bool`)
            Pass true if the chat should be removed from the chat list
        
        revoke (:class:`bool`)
            Pass true to try to delete chat history for all users
        
    """

    ID: str = Field("deleteChatHistory", alias="@type")
    chat_id: int
    remove_from_chat_list: bool
    revoke: bool

    @staticmethod
    def read(q: dict) -> DeleteChatHistory:
        return DeleteChatHistory.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteAllRevokedChatInviteLinks(BaseObject):
    """
    Deletes all revoked chat invite links created by a given chat administrator. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        creator_user_id (:class:`int`)
            User identifier of a chat administrator, which links will be deleted. Must be an identifier of the current user for non-owner
        
    """

    ID: str = Field("deleteAllRevokedChatInviteLinks", alias="@type")
    chat_id: int
    creator_user_id: int

    @staticmethod
    def read(q: dict) -> DeleteAllRevokedChatInviteLinks:
        return DeleteAllRevokedChatInviteLinks.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class RemoveRecentSticker(BaseObject):
    """
    Removes a sticker from the list of recently used stickers
    
    Params:
        is_attached (:class:`bool`)
            Pass true to remove the sticker from the list of stickers recently attached to photo or video files; pass false to remove the sticker from the list of recently sent stickers
        
        sticker (:class:`InputFile`)
            Sticker file to delete
        
    """

    ID: str = Field("removeRecentSticker", alias="@type")
    is_attached: bool
    sticker: InputFile

    @staticmethod
    def read(q: dict) -> RemoveRecentSticker:
        return RemoveRecentSticker.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .animation import Animation
from ..base_object import BaseObject


class Animations(BaseObject):
    """
    Represents a list of animations
    
    Params:
        animations (:obj:`list[Animation]`)
            List of animations
        
    """

    ID: str = Field("animations", alias="@type")
    animations: list[Animation]

    @staticmethod
    def read(q: dict) -> Animations:
        return Animations.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GroupCallJoinResponseCandidate(BaseObject):
    """
    Describes a join response candidate for interaction with tgcalls
    
    Params:
        port (:class:`str`)
            Value of the field port
        
        protocol (:class:`str`)
            Value of the field protocol
        
        network (:class:`str`)
            Value of the field network
        
        generation (:class:`str`)
            Value of the field generation
        
        id (:class:`str`)
            Value of the field id
        
        component (:class:`str`)
            Value of the field component
        
        foundation (:class:`str`)
            Value of the field foundation
        
        priority (:class:`str`)
            Value of the field priority
        
        ip (:class:`str`)
            Value of the field ip
        
        type_ (:class:`str`)
            Value of the field type
        
        tcp_type (:class:`str`)
            Value of the field tcp_type
        
        rel_addr (:class:`str`)
            Value of the field rel_addr
        
        rel_port (:class:`str`)
            Value of the field rel_port
        
    """

    ID: str = Field("groupCallJoinResponseCandidate", alias="@type")
    port: str
    protocol: str
    network: str
    generation: str
    id: str
    component: str
    foundation: str
    priority: str
    ip: str
    type_: str = Field(..., alias='type')
    tcp_type: str
    rel_addr: str
    rel_port: str

    @staticmethod
    def read(q: dict) -> GroupCallJoinResponseCandidate:
        return GroupCallJoinResponseCandidate.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .animation import Animation
from .formatted_text import FormattedText
from .photo import Photo
from ..base_object import BaseObject


class Game(BaseObject):
    """
    Describes a game
    
    Params:
        id (:class:`int`)
            Game ID
        
        short_name (:class:`str`)
            Game short name. To share a game use the URL https://t.me/{bot_username}?game={game_short_name}
        
        title (:class:`str`)
            Game title
        
        text (:class:`FormattedText`)
            Game text, usually containing scoreboards for a game
        
        param_description (:class:`str`)
            Game description
        
        photo (:class:`Photo`)
            Game photo
        
        animation (:class:`Animation`)
            Game animation; may be null
        
    """

    ID: str = Field("game", alias="@type")
    id: int
    short_name: str
    title: str
    text: FormattedText
    param_description: str
    photo: Photo
    animation: typing.Optional[Animation] = None

    @staticmethod
    def read(q: dict) -> Game:
        return Game.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import BackgroundType


class GetBackgroundUrl(BaseObject):
    """
    Constructs a persistent HTTP URL for a background
    
    Params:
        name (:class:`str`)
            Background name
        
        type_ (:class:`BackgroundType`)
            Background type
        
    """

    ID: str = Field("getBackgroundUrl", alias="@type")
    name: str
    type_: BackgroundType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> GetBackgroundUrl:
        return GetBackgroundUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TerminateSession(BaseObject):
    """
    Terminates a session of the current user
    
    Params:
        session_id (:class:`int`)
            Session identifier
        
    """

    ID: str = Field("terminateSession", alias="@type")
    session_id: int

    @staticmethod
    def read(q: dict) -> TerminateSession:
        return TerminateSession.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .keyboard_button_type import KeyboardButtonType
from ..base_object import BaseObject


class KeyboardButton(BaseObject):
    """
    Represents a single button in a bot keyboard
    
    Params:
        text (:class:`str`)
            Text of the button
        
        type_ (:class:`KeyboardButtonType`)
            Type of the button
        
    """

    ID: str = Field("keyboardButton", alias="@type")
    text: str
    type_: KeyboardButtonType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> KeyboardButton:
        return KeyboardButton.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetMessageLink(BaseObject):
    """
    Returns an HTTPS link to a message in a chat. Available only for already sent messages in supergroups and channels. This is an offline request
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to which the message belongs
        
        message_id (:class:`int`)
            Identifier of the message
        
        for_album (:class:`bool`)
            Pass true to create a link for the whole media album
        
        for_comment (:class:`bool`)
            Pass true to create a link to the message as a channel post comment, or from a message thread
        
    """

    ID: str = Field("getMessageLink", alias="@type")
    chat_id: int
    message_id: int
    for_album: bool
    for_comment: bool

    @staticmethod
    def read(q: dict) -> GetMessageLink:
        return GetMessageLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LoginUrlInfo(BaseObject):
    """
    Contains information about an inline button of type inlineKeyboardButtonTypeLoginUrl
    
    """

    ID: str = Field("loginUrlInfo", alias="@type")


class LoginUrlInfoOpen(LoginUrlInfo):
    """
    An HTTP url needs to be open
    
    Params:
        url (:class:`str`)
            The URL to open
        
        skip_confirm (:class:`bool`)
            True, if there is no need to show an ordinary open URL confirm
        
    """

    ID: str = Field("loginUrlInfoOpen", alias="@type")
    url: str
    skip_confirm: bool

    @staticmethod
    def read(q: dict) -> LoginUrlInfoOpen:
        return LoginUrlInfoOpen.construct(**q)


class LoginUrlInfoRequestConfirmation(LoginUrlInfo):
    """
    An authorization confirmation dialog needs to be shown to the user
    
    Params:
        url (:class:`str`)
            An HTTP URL to be opened
        
        domain (:class:`str`)
            A domain of the URL
        
        bot_user_id (:class:`int`)
            User identifier of a bot linked with the website
        
        request_write_access (:class:`bool`)
            True, if the user needs to be requested to give the permission to the bot to send them messages
        
    """

    ID: str = Field("loginUrlInfoRequestConfirmation", alias="@type")
    url: str
    domain: str
    bot_user_id: int
    request_write_access: bool

    @staticmethod
    def read(q: dict) -> LoginUrlInfoRequestConfirmation:
        return LoginUrlInfoRequestConfirmation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .message import Message
from ..base_object import BaseObject


class Messages(BaseObject):
    """
    Contains a list of messages
    
    Params:
        total_count (:class:`int`)
            Approximate total count of messages found
        
        messages (:obj:`list[Message]`)
            List of messages; messages may be null
        
    """

    ID: str = Field("messages", alias="@type")
    total_count: int
    messages: list[typing.Optional[Message]] = None

    @staticmethod
    def read(q: dict) -> Messages:
        return Messages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteAccount(BaseObject):
    """
    Deletes the account of the current user, deleting all information associated with the user from the server. The phone number of the account can be used to create a new account. Can be called before authorization when the current authorization state is authorizationStateWaitPassword
    
    Params:
        reason (:class:`str`)
            The reason why the account was deleted; optional
        
    """

    ID: str = Field("deleteAccount", alias="@type")
    reason: str

    @staticmethod
    def read(q: dict) -> DeleteAccount:
        return DeleteAccount.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetChatDiscussionGroup(BaseObject):
    """
    Changes the discussion group of a channel chat; requires can_change_info administrator right in the channel if it is specified
    
    Params:
        chat_id (:class:`int`)
            Identifier of the channel chat. Pass 0 to remove a link from the supergroup passed in the second argument to a linked channel chat (requires can_pin_messages rights in the supergroup)
        
        discussion_chat_id (:class:`int`)
            Identifier of a new channel's discussion group. Use 0 to remove the discussion group. Use the method getSuitableDiscussionChats to find all suitable groups. Basic group chats must be first upgraded to supergroup chats. If new chat members don't have access to old messages in the supergroup, then toggleSupergroupIsAllHistoryAvailable must be used first to change that
        
    """

    ID: str = Field("setChatDiscussionGroup", alias="@type")
    chat_id: int
    discussion_chat_id: int

    @staticmethod
    def read(q: dict) -> SetChatDiscussionGroup:
        return SetChatDiscussionGroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetGroupCallParticipantIsSpeaking(BaseObject):
    """
    Informs TDLib that a group call participant speaking state has changed
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
        source (:class:`int`)
            Group call participant's synchronization source identifier, or 0 for the current user
        
        is_speaking (:class:`bool`)
            True, if the user is speaking
        
    """

    ID: str = Field("setGroupCallParticipantIsSpeaking", alias="@type")
    group_call_id: int
    source: int
    is_speaking: bool

    @staticmethod
    def read(q: dict) -> SetGroupCallParticipantIsSpeaking:
        return SetGroupCallParticipantIsSpeaking.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteProfilePhoto(BaseObject):
    """
    Deletes a profile photo
    
    Params:
        profile_photo_id (:class:`int`)
            Identifier of the profile photo to delete
        
    """

    ID: str = Field("deleteProfilePhoto", alias="@type")
    profile_photo_id: int

    @staticmethod
    def read(q: dict) -> DeleteProfilePhoto:
        return DeleteProfilePhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetExternalLink(BaseObject):
    """
    Returns an HTTP URL which can be used to automatically authorize the current user on a website after clicking an HTTP link. Use the method getExternalLinkInfo to find whether a prior user confirmation is needed
    
    Params:
        link (:class:`str`)
            The HTTP link
        
        allow_write_access (:class:`bool`)
            True, if the current user allowed the bot, returned in getExternalLinkInfo, to send them messages
        
    """

    ID: str = Field("getExternalLink", alias="@type")
    link: str
    allow_write_access: bool

    @staticmethod
    def read(q: dict) -> GetExternalLink:
        return GetExternalLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetInactiveSupergroupChats(BaseObject):
    """
    Returns a list of recently inactive supergroups and channels. Can be used when user reaches limit on the number of joined supergroups and channels and receives CHANNELS_TOO_MUCH error
    
    """

    ID: str = Field("getInactiveSupergroupChats", alias="@type")

    @staticmethod
    def read(q: dict) -> GetInactiveSupergroupChats:
        return GetInactiveSupergroupChats.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class UserStatus(BaseObject):
    """
    Describes the last time the user was online
    
    """

    ID: str = Field("userStatus", alias="@type")


class UserStatusEmpty(UserStatus):
    """
    The user status was never changed
    
    """

    ID: str = Field("userStatusEmpty", alias="@type")

    @staticmethod
    def read(q: dict) -> UserStatusEmpty:
        return UserStatusEmpty.construct(**q)


class UserStatusLastMonth(UserStatus):
    """
    The user is offline, but was online last month
    
    """

    ID: str = Field("userStatusLastMonth", alias="@type")

    @staticmethod
    def read(q: dict) -> UserStatusLastMonth:
        return UserStatusLastMonth.construct(**q)


class UserStatusLastWeek(UserStatus):
    """
    The user is offline, but was online last week
    
    """

    ID: str = Field("userStatusLastWeek", alias="@type")

    @staticmethod
    def read(q: dict) -> UserStatusLastWeek:
        return UserStatusLastWeek.construct(**q)


class UserStatusOffline(UserStatus):
    """
    The user is offline
    
    Params:
        was_online (:class:`int`)
            Point in time (Unix timestamp) when the user was last online
        
    """

    ID: str = Field("userStatusOffline", alias="@type")
    was_online: int

    @staticmethod
    def read(q: dict) -> UserStatusOffline:
        return UserStatusOffline.construct(**q)


class UserStatusOnline(UserStatus):
    """
    The user is online
    
    Params:
        expires (:class:`int`)
            Point in time (Unix timestamp) when the user's online status will expire
        
    """

    ID: str = Field("userStatusOnline", alias="@type")
    expires: int

    @staticmethod
    def read(q: dict) -> UserStatusOnline:
        return UserStatusOnline.construct(**q)


class UserStatusRecently(UserStatus):
    """
    The user was online recently
    
    """

    ID: str = Field("userStatusRecently", alias="@type")

    @staticmethod
    def read(q: dict) -> UserStatusRecently:
        return UserStatusRecently.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class FileType(BaseObject):
    """
    Represents the type of a file
    
    """

    ID: str = Field("fileType", alias="@type")


class FileTypeAnimation(FileType):
    """
    The file is an animation
    
    """

    ID: str = Field("fileTypeAnimation", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeAnimation:
        return FileTypeAnimation.construct(**q)


class FileTypeAudio(FileType):
    """
    The file is an audio file
    
    """

    ID: str = Field("fileTypeAudio", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeAudio:
        return FileTypeAudio.construct(**q)


class FileTypeDocument(FileType):
    """
    The file is a document
    
    """

    ID: str = Field("fileTypeDocument", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeDocument:
        return FileTypeDocument.construct(**q)


class FileTypeNone(FileType):
    """
    The data is not a file
    
    """

    ID: str = Field("fileTypeNone", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeNone:
        return FileTypeNone.construct(**q)


class FileTypePhoto(FileType):
    """
    The file is a photo
    
    """

    ID: str = Field("fileTypePhoto", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypePhoto:
        return FileTypePhoto.construct(**q)


class FileTypeProfilePhoto(FileType):
    """
    The file is a profile photo
    
    """

    ID: str = Field("fileTypeProfilePhoto", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeProfilePhoto:
        return FileTypeProfilePhoto.construct(**q)


class FileTypeSecret(FileType):
    """
    The file was sent to a secret chat (the file type is not known to the server)
    
    """

    ID: str = Field("fileTypeSecret", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeSecret:
        return FileTypeSecret.construct(**q)


class FileTypeSecretThumbnail(FileType):
    """
    The file is a thumbnail of a file from a secret chat
    
    """

    ID: str = Field("fileTypeSecretThumbnail", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeSecretThumbnail:
        return FileTypeSecretThumbnail.construct(**q)


class FileTypeSecure(FileType):
    """
    The file is a file from Secure storage used for storing Telegram Passport files
    
    """

    ID: str = Field("fileTypeSecure", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeSecure:
        return FileTypeSecure.construct(**q)


class FileTypeSticker(FileType):
    """
    The file is a sticker
    
    """

    ID: str = Field("fileTypeSticker", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeSticker:
        return FileTypeSticker.construct(**q)


class FileTypeThumbnail(FileType):
    """
    The file is a thumbnail of another file
    
    """

    ID: str = Field("fileTypeThumbnail", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeThumbnail:
        return FileTypeThumbnail.construct(**q)


class FileTypeUnknown(FileType):
    """
    The file type is not yet known
    
    """

    ID: str = Field("fileTypeUnknown", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeUnknown:
        return FileTypeUnknown.construct(**q)


class FileTypeVideo(FileType):
    """
    The file is a video
    
    """

    ID: str = Field("fileTypeVideo", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeVideo:
        return FileTypeVideo.construct(**q)


class FileTypeVideoNote(FileType):
    """
    The file is a video note
    
    """

    ID: str = Field("fileTypeVideoNote", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeVideoNote:
        return FileTypeVideoNote.construct(**q)


class FileTypeVoiceNote(FileType):
    """
    The file is a voice note
    
    """

    ID: str = Field("fileTypeVoiceNote", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeVoiceNote:
        return FileTypeVoiceNote.construct(**q)


class FileTypeWallpaper(FileType):
    """
    The file is a wallpaper or a background pattern
    
    """

    ID: str = Field("fileTypeWallpaper", alias="@type")

    @staticmethod
    def read(q: dict) -> FileTypeWallpaper:
        return FileTypeWallpaper.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .labeled_price_part import LabeledPricePart
from ..base_object import BaseObject


class Invoice(BaseObject):
    """
    Product invoice
    
    Params:
        currency (:class:`str`)
            ISO 4217 currency code
        
        price_parts (:obj:`list[LabeledPricePart]`)
            A list of objects used to calculate the total price of the product
        
        is_test (:class:`bool`)
            True, if the payment is a test payment
        
        need_name (:class:`bool`)
            True, if the user's name is needed for payment
        
        need_phone_number (:class:`bool`)
            True, if the user's phone number is needed for payment
        
        need_email_address (:class:`bool`)
            True, if the user's email address is needed for payment
        
        need_shipping_address (:class:`bool`)
            True, if the user's shipping address is needed for payment
        
        send_phone_number_to_provider (:class:`bool`)
            True, if the user's phone number will be sent to the provider
        
        send_email_address_to_provider (:class:`bool`)
            True, if the user's email address will be sent to the provider
        
        is_flexible (:class:`bool`)
            True, if the total price depends on the shipping method
        
    """

    ID: str = Field("invoice", alias="@type")
    currency: str
    price_parts: list[LabeledPricePart]
    is_test: bool
    need_name: bool
    need_phone_number: bool
    need_email_address: bool
    need_shipping_address: bool
    send_phone_number_to_provider: bool
    send_email_address_to_provider: bool
    is_flexible: bool

    @staticmethod
    def read(q: dict) -> Invoice:
        return Invoice.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .inline_keyboard_button_type import InlineKeyboardButtonType
from ..base_object import BaseObject


class InlineKeyboardButton(BaseObject):
    """
    Represents a single button in an inline keyboard
    
    Params:
        text (:class:`str`)
            Text of the button
        
        type_ (:class:`InlineKeyboardButtonType`)
            Type of the button
        
    """

    ID: str = Field("inlineKeyboardButton", alias="@type")
    text: str
    type_: InlineKeyboardButtonType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> InlineKeyboardButton:
        return InlineKeyboardButton.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LanguagePackStringValue(BaseObject):
    """
    Represents the value of a string in a language pack
    
    """

    ID: str = Field("languagePackStringValue", alias="@type")


class LanguagePackStringValueDeleted(LanguagePackStringValue):
    """
    A deleted language pack string, the value should be taken from the built-in english language pack
    
    """

    ID: str = Field("languagePackStringValueDeleted", alias="@type")

    @staticmethod
    def read(q: dict) -> LanguagePackStringValueDeleted:
        return LanguagePackStringValueDeleted.construct(**q)


class LanguagePackStringValueOrdinary(LanguagePackStringValue):
    """
    An ordinary language pack string
    
    Params:
        value (:class:`str`)
            String value
        
    """

    ID: str = Field("languagePackStringValueOrdinary", alias="@type")
    value: str

    @staticmethod
    def read(q: dict) -> LanguagePackStringValueOrdinary:
        return LanguagePackStringValueOrdinary.construct(**q)


class LanguagePackStringValuePluralized(LanguagePackStringValue):
    """
    A language pack string which has different forms based on the number of some object it mentions. See https://www.unicode.org/cldr/charts/latest/supplemental/language_plural_rules.html for more info
    
    Params:
        zero_value (:class:`str`)
            Value for zero objects
        
        one_value (:class:`str`)
            Value for one object
        
        two_value (:class:`str`)
            Value for two objects
        
        few_value (:class:`str`)
            Value for few objects
        
        many_value (:class:`str`)
            Value for many objects
        
        other_value (:class:`str`)
            Default value
        
    """

    ID: str = Field("languagePackStringValuePluralized", alias="@type")
    zero_value: str
    one_value: str
    two_value: str
    few_value: str
    many_value: str
    other_value: str

    @staticmethod
    def read(q: dict) -> LanguagePackStringValuePluralized:
        return LanguagePackStringValuePluralized.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RemoveNotificationGroup(BaseObject):
    """
    Removes a group of active notifications. Needs to be called only if the notification group is removed by the current user
    
    Params:
        notification_group_id (:class:`int`)
            Notification group identifier
        
        max_notification_id (:class:`int`)
            The maximum identifier of removed notifications
        
    """

    ID: str = Field("removeNotificationGroup", alias="@type")
    notification_group_id: int
    max_notification_id: int

    @staticmethod
    def read(q: dict) -> RemoveNotificationGroup:
        return RemoveNotificationGroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import PhoneNumberAuthenticationSettings


class SendPhoneNumberConfirmationCode(BaseObject):
    """
    Sends phone number confirmation code. Should be called when user presses "https://t.me/confirmphone?phone=*******&hash=**********" or "tg://confirmphone?phone=*******&hash=**********" link
    
    Params:
        hash_ (:class:`str`)
            Value of the "hash" parameter from the link
        
        phone_number (:class:`str`)
            Value of the "phone" parameter from the link
        
        settings (:class:`PhoneNumberAuthenticationSettings`)
            Settings for the authentication of the user's phone number
        
    """

    ID: str = Field("sendPhoneNumberConfirmationCode", alias="@type")
    hash_: str = Field(..., alias='hash')
    phone_number: str
    settings: PhoneNumberAuthenticationSettings

    @staticmethod
    def read(q: dict) -> SendPhoneNumberConfirmationCode:
        return SendPhoneNumberConfirmationCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class BankCardActionOpenUrl(BaseObject):
    """
    Describes an action associated with a bank card number
    
    Params:
        text (:class:`str`)
            Action text
        
        url (:class:`str`)
            The URL to be opened
        
    """

    ID: str = Field("bankCardActionOpenUrl", alias="@type")
    text: str
    url: str

    @staticmethod
    def read(q: dict) -> BankCardActionOpenUrl:
        return BankCardActionOpenUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatReportReason


class ReportChatPhoto(BaseObject):
    """
    Reports a chat photo to the Telegram moderators. A chat photo can be reported only if this is a private chat with a bot, a private chat with a user sharing their location, a supergroup, or a channel, since other chats can't be checked by moderators
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        file_id (:class:`int`)
            Identifier of the photo to report. Only full photos from chatPhoto can be reported
        
        reason (:class:`ChatReportReason`)
            The reason for reporting the chat photo
        
        text (:class:`str`)
            Additional report details; 0-1024 characters
        
    """

    ID: str = Field("reportChatPhoto", alias="@type")
    chat_id: int
    file_id: int
    reason: ChatReportReason
    text: typing.Optional[str] = Field(None, max_length=1024)

    @staticmethod
    def read(q: dict) -> ReportChatPhoto:
        return ReportChatPhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import BackgroundType, InputBackground


class SetBackground(BaseObject):
    """
    Changes the background selected by the user; adds background to the list of installed backgrounds
    
    Params:
        background (:class:`InputBackground`)
            The input background to use, null for filled backgrounds
        
        type_ (:class:`BackgroundType`)
            Background type; null for default background. The method will return error 404 if type is null
        
        for_dark_theme (:class:`bool`)
            True, if the background is chosen for dark theme
        
    """

    ID: str = Field("setBackground", alias="@type")
    background: InputBackground
    type_: BackgroundType = Field(..., alias='type')
    for_dark_theme: bool

    @staticmethod
    def read(q: dict) -> SetBackground:
        return SetBackground.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Location(BaseObject):
    """
    Describes a location on planet Earth
    
    Params:
        latitude (:class:`float`)
            Latitude of the location in degrees; as defined by the sender
        
        longitude (:class:`float`)
            Longitude of the location, in degrees; as defined by the sender
        
        horizontal_accuracy (:class:`float`)
            The estimated horizontal accuracy of the location, in meters; as defined by the sender. 0 if unknown
        
    """

    ID: str = Field("location", alias="@type")
    latitude: float
    longitude: float
    horizontal_accuracy: float

    @staticmethod
    def read(q: dict) -> Location:
        return Location.construct(**q)



import json
import logging
import platform
import typing
from ctypes import *
from enum import IntEnum

import pkg_resources

fatal_error_callback_type = CFUNCTYPE(None, c_char_p)

TDLIB_VERSION = '1.7.3'
TDLIB_MAX_INT = 2 ** 63 - 1


def _get_tdjson_lib_path() -> str:
    if platform.system().lower() == 'darwin':
        lib_extension = 'dylib'
    elif platform.system().lower() == 'windows':
        lib_extension = 'dll'
    else:
        lib_extension = 'so'

    lib_name = f"libtdjson.{TDLIB_VERSION}.{lib_extension}"

    return pkg_resources.resource_filename('aiotdlib', f'tdlib/{lib_name}')


class TDLibLogVerbosity(IntEnum):
    FATAL = 0
    ERROR = 1
    WARNING = 2
    INFO = 3
    DEBUG = 4
    VERBOSE = 5
    MAXIMUM = 1023


class TDJson:
    logger: logging.Logger

    # TDLib functions typings
    __tdjson: CDLL
    __td_json_client_create: typing.Callable[[], int]
    __td_json_client_receive: typing.Callable[[int, float], bytes]
    __td_json_client_send: typing.Callable[[int, bytes], None]
    __td_json_client_execute: typing.Callable[[int, bytes], bytes]
    __td_json_client_destroy: typing.Callable[[int], None]
    __td_set_log_verbosity_level: typing.Callable[[int], None]
    __td_set_log_fatal_error_callback: typing.Callable[[fatal_error_callback_type], None]
    __c_on_fatal_error_callback: typing.Callable[[fatal_error_callback_type], None]

    td_json_client: typing.Optional[int] = None

    def __init__(self, library_path: str = None, verbosity: TDLibLogVerbosity = TDLibLogVerbosity.WARNING) -> None:
        if library_path is None:
            library_path = _get_tdjson_lib_path()

        if library_path is None:
            raise ValueError('Unable to find TD library binaries')

        self.logger = logging.getLogger(__name__)
        self.logger.info('Using shared library "%s"', library_path)
        self.initialize(library_path, verbosity)

    def __del__(self) -> None:
        self.stop()

    def initialize(self, library_path: str, verbosity: TDLibLogVerbosity) -> None:
        if bool(self.td_json_client):
            raise RuntimeError('TDJson instance is already initialized')

        # load TDLib functions from shared library
        self.__tdjson = CDLL(library_path)

        # td_json_client_create
        self.__td_json_client_create = self.__tdjson.td_json_client_create
        self.__td_json_client_create.restype = c_void_p
        self.__td_json_client_create.argtypes = []

        # Creating tdlib json client instance
        self.td_json_client = self.__td_json_client_create()

        # td_json_client_receive
        self.__td_json_client_receive = self.__tdjson.td_json_client_receive
        self.__td_json_client_receive.restype = c_char_p
        self.__td_json_client_receive.argtypes = [c_void_p, c_double]

        # td_json_client_send
        self.__td_json_client_send = self.__tdjson.td_json_client_send
        self.__td_json_client_send.restype = None
        self.__td_json_client_send.argtypes = [c_void_p, c_char_p]

        # td_json_client_execute
        self.__td_json_client_execute = self.__tdjson.td_json_client_execute
        self.__td_json_client_execute.restype = c_char_p
        self.__td_json_client_execute.argtypes = [c_void_p, c_char_p]

        # td_json_client_destroy
        self.__td_json_client_destroy = self.__tdjson.td_json_client_destroy
        self.__td_json_client_destroy.restype = None
        self.__td_json_client_destroy.argtypes = [c_void_p]

        # td_set_log_verbosity_level
        self.__td_set_log_verbosity_level = self.__tdjson.td_set_log_verbosity_level
        self.__td_set_log_verbosity_level.restype = None
        self.__td_set_log_verbosity_level.argtypes = [c_int]
        self.__td_set_log_verbosity_level(int(verbosity))

        # td_set_log_fatal_error_callback
        self.__td_set_log_fatal_error_callback = self.__tdjson.td_set_log_fatal_error_callback
        self.__td_set_log_fatal_error_callback.restype = None
        self.__td_set_log_fatal_error_callback.argtypes = [fatal_error_callback_type]
        c_on_fatal_error_callback = fatal_error_callback_type(self.__on_fatal_error_callback)
        self.__td_set_log_fatal_error_callback(c_on_fatal_error_callback)

    def __on_fatal_error_callback(self, error_message: str) -> None:
        self.logger.error('TDLib fatal error: %s', error_message)

    def send(self, query: dict):
        if not bool(self.td_json_client):
            raise RuntimeError('Instance is not initialized')

        # TODO: Add support for orjson for better encoding/decoding performance
        dumped_query = json.dumps(query).encode('utf-8')
        self.logger.debug(f'[me >>>] Sending {dumped_query}')
        self.__td_json_client_send(self.td_json_client, dumped_query)

    def execute(self, query: dict) -> typing.Optional[dict]:
        if not bool(self.td_json_client):
            raise RuntimeError('Instance is not initialized')

        # TODO: Add support for orjson for better encoding/decoding performance
        dumped_query = json.dumps(query).encode('utf-8')
        self.logger.debug(f'Executing query {dumped_query} as client {self.td_json_client}')
        result = self.__td_json_client_execute(self.td_json_client, dumped_query)

        if result:
            result = json.loads(result)

        return result

    def receive(self, timeout: float = 1.0) -> typing.Optional[dict]:
        if not bool(self.td_json_client):
            raise RuntimeError('Instance is not initialized')

        result = self.__td_json_client_receive(self.td_json_client, timeout)

        if result:
            self.logger.debug(f'[me <<<] Received {result}')
            result = json.loads(result)

        return result

    def stop(self) -> None:
        if bool(self.td_json_client) and callable(self.__td_json_client_destroy):
            self.logger.warning('Destroying TDJson client')
            td_json_client = self.td_json_client
            self.td_json_client = None
            self.__td_json_client_destroy(td_json_client)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TransferChatOwnership(BaseObject):
    """
    Changes the owner of a chat. The current user must be a current owner of the chat. Use the method canTransferOwnership to check whether the ownership can be transferred from the current session. Available only for supergroups and channel chats
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        user_id (:class:`int`)
            Identifier of the user to which transfer the ownership. The ownership can't be transferred to a bot or to a deleted user
        
        password (:class:`str`)
            The password of the current user
        
    """

    ID: str = Field("transferChatOwnership", alias="@type")
    chat_id: int
    user_id: int
    password: str

    @staticmethod
    def read(q: dict) -> TransferChatOwnership:
        return TransferChatOwnership.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import NotificationSettingsScope


class GetChatNotificationSettingsExceptions(BaseObject):
    """
    Returns list of chats with non-default notification settings
    
    Params:
        scope (:class:`NotificationSettingsScope`)
            If specified, only chats from the specified scope will be returned
        
        compare_sound (:class:`bool`)
            If true, also chats with non-default sound will be returned
        
    """

    ID: str = Field("getChatNotificationSettingsExceptions", alias="@type")
    scope: NotificationSettingsScope
    compare_sound: bool

    @staticmethod
    def read(q: dict) -> GetChatNotificationSettingsExceptions:
        return GetChatNotificationSettingsExceptions.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ConnectionState(BaseObject):
    """
    Describes the current state of the connection to Telegram servers
    
    """

    ID: str = Field("connectionState", alias="@type")


class ConnectionStateConnecting(ConnectionState):
    """
    Currently establishing a connection to the Telegram servers
    
    """

    ID: str = Field("connectionStateConnecting", alias="@type")

    @staticmethod
    def read(q: dict) -> ConnectionStateConnecting:
        return ConnectionStateConnecting.construct(**q)


class ConnectionStateConnectingToProxy(ConnectionState):
    """
    Currently establishing a connection with a proxy server
    
    """

    ID: str = Field("connectionStateConnectingToProxy", alias="@type")

    @staticmethod
    def read(q: dict) -> ConnectionStateConnectingToProxy:
        return ConnectionStateConnectingToProxy.construct(**q)


class ConnectionStateReady(ConnectionState):
    """
    There is a working connection to the Telegram servers
    
    """

    ID: str = Field("connectionStateReady", alias="@type")

    @staticmethod
    def read(q: dict) -> ConnectionStateReady:
        return ConnectionStateReady.construct(**q)


class ConnectionStateUpdating(ConnectionState):
    """
    Downloading data received while the application was offline
    
    """

    ID: str = Field("connectionStateUpdating", alias="@type")

    @staticmethod
    def read(q: dict) -> ConnectionStateUpdating:
        return ConnectionStateUpdating.construct(**q)


class ConnectionStateWaitingForNetwork(ConnectionState):
    """
    Currently waiting for the network to become available. Use setNetworkType to change the available network type
    
    """

    ID: str = Field("connectionStateWaitingForNetwork", alias="@type")

    @staticmethod
    def read(q: dict) -> ConnectionStateWaitingForNetwork:
        return ConnectionStateWaitingForNetwork.construct(**q)
